ABORTDOC=2
ABSOLUTE=1
ACCESS_ALLOWED_ACE_TYPE=0
ACCESS_DENIED_ACE_TYPE=1
ACCESS_FILTERKEYS=2
ACCESS_MOUSEKEYS=3
ACCESS_STICKYKEYS=1
ACCESS_SYSTEM_SECURITY=16777216
ACL_REVISION=2
ACL_REVISION1=1
ACL_REVISION2=2
AC_LINE_BACKUP_POWER=2
AC_LINE_OFFLINE=0
AC_LINE_ONLINE=1
AC_LINE_UNKNOWN=255
AC_SRC_ALPHA=1
AC_SRC_OVER=0
AD_CLOCKWISE=2
AD_COUNTERCLOCKWISE=1
ALERT_SYSTEM_CRITICAL=5
ALERT_SYSTEM_ERROR=3
ALERT_SYSTEM_INFORMATIONAL=1
ALERT_SYSTEM_QUERY=4
ALERT_SYSTEM_WARNING=2
ALTERNATE=1
ANSI_CHARSET=0
ANSI_FIXED_FONT=11
ANSI_VAR_FONT=12
ANTIALIASED_QUALITY=4
APPLICATION_ERROR_MASK=536870912
ARABIC_CHARSET=178
ARW_BOTTOMLEFT=0
ARW_BOTTOMRIGHT=1
ARW_DOWN=4
ARW_HIDE=8
ARW_LEFT=0
ARW_RIGHT=0
ARW_STARTMASK=3
ARW_STARTRIGHT=1
ARW_STARTTOP=2
ARW_TOPLEFT=2
ARW_TOPRIGHT=3
ARW_UP=4
ASPECTX=40
ASPECTXY=44
ASPECTY=42
ASPECT_FILTERING=1
ATF_ONOFFFEEDBACK=2
ATF_TIMEOUTON=1
AW_ACTIVATE=131072
AW_BLEND=524288
AW_CENTER=16
AW_HIDE=65536
AW_HOR_NEGATIVE=2
AW_HOR_POSITIVE=1
AW_SLIDE=262144
AW_VER_NEGATIVE=8
AW_VER_POSITIVE=4
BACKUP_ALTERNATE_DATA=4
BACKUP_DATA=1
BACKUP_EA_DATA=2
BACKUP_INVALID=0
BACKUP_LINK=5
BACKUP_OBJECT_ID=7
BACKUP_PROPERTY_DATA=6
BACKUP_REPARSE_DATA=8
BACKUP_SECURITY_DATA=3
BACKUP_SPARSE_BLOCK=9
BALTIC_CHARSET=186
BANDINFO=24
BATTERY_FLAG_CHARGING=8
BATTERY_FLAG_CRITICAL=4
BATTERY_FLAG_HIGH=1
BATTERY_FLAG_LOW=2
BATTERY_FLAG_NO_BATTERY=128
BATTERY_FLAG_UNKNOWN=255
BATTERY_LIFE_UNKNOWN=-1
BATTERY_PERCENTAGE_UNKNOWN=255
BDR_INNER=12
BDR_OUTER=3
BDR_RAISEDINNER=4
BDR_RAISEDOUTER=1
BDR_SUNKENINNER=8
BDR_SUNKENOUTER=2
BEGIN_PATH=4096
BF_ADJUST=8192
BF_BOTTOM=8
BF_BOTTOMLEFT=9
BF_BOTTOMRIGHT=12
BF_DIAGONAL=16
BF_DIAGONAL_ENDBOTTOMLEFT=25
BF_DIAGONAL_ENDBOTTOMRIGHT=28
BF_DIAGONAL_ENDTOPLEFT=19
BF_DIAGONAL_ENDTOPRIGHT=22
BF_FLAT=16384
BF_LEFT=1
BF_MIDDLE=2048
BF_MONO=32768
BF_RECT=15
BF_RIGHT=4
BF_SOFT=4096
BF_TOP=2
BF_TOPLEFT=3
BF_TOPRIGHT=6
BITSPIXEL=12
BI_BITFIELDS=3
BI_RGB=0
BI_RLE4=2
BI_RLE8=1
BKMODE_LAST=2
BLACKNESS=66
BLACKONWHITE=1
BLACK_BRUSH=4
BLACK_PEN=7
BLTALIGNMENT=119
BM_CLICK=245
BM_GETCHECK=240
BM_GETIMAGE=246
BM_GETSTATE=242
BM_SETCHECK=241
BM_SETIMAGE=247
BM_SETSTATE=243
BM_SETSTYLE=244
BN_CLICKED=0
BN_DBLCLK=5
BN_DISABLE=4
BN_DOUBLECLICKED=5
BN_HILITE=2
BN_KILLFOCUS=7
BN_PAINT=1
BN_PUSHED=2
BN_SETFOCUS=6
BN_UNHILITE=3
BN_UNPUSHED=3
BOLD_FONTTYPE=256
BROADCAST_QUERY_DENY=1112363332
BSF_FLUSHDISK=4
BSF_FORCEIFHUNG=32
BSF_IGNORECURRENTTASK=2
BSF_MSGSRV32ISOK=-2147483648
BSF_MSGSRV32ISOK_BIT=31
BSF_NOHANG=8
BSF_NOTIMEOUTIFNOTHUNG=64
BSF_POSTMESSAGE=16
BSF_QUERY=1
BSM_ALLCOMPONENTS=0
BSM_ALLDESKTOPS=16
BSM_APPLICATIONS=8
BSM_INSTALLABLEDRIVERS=4
BSM_NETDRIVER=2
BSM_VXDS=1
BST_CHECKED=1
BST_FOCUS=8
BST_INDETERMINATE=2
BST_PUSHED=4
BST_UNCHECKED=0
BS_3STATE=5
BS_AUTO3STATE=6
BS_AUTOCHECKBOX=3
BS_AUTORADIOBUTTON=9
BS_BITMAP=128
BS_BOTTOM=2048
BS_CENTER=768
BS_CHECKBOX=2
BS_DEFPUSHBUTTON=1
BS_DIBPATTERN=5
BS_DIBPATTERN8X8=8
BS_DIBPATTERNPT=6
BS_FLAT=32768
BS_GROUPBOX=7
BS_HATCHED=2
BS_HOLLOW=1
BS_ICON=64
BS_INDEXED=4
BS_LEFT=256
BS_LEFTTEXT=32
BS_MULTILINE=8192
BS_NOTIFY=16384
BS_NULL=1
BS_OWNERDRAW=11
BS_PATTERN=3
BS_PATTERN8X8=7
BS_PUSHBUTTON=0
BS_PUSHLIKE=4096
BS_RADIOBUTTON=4
BS_RIGHT=512
BS_RIGHTBUTTON=32
BS_SOLID=0
BS_TEXT=0
BS_TOP=1024
BS_USERBUTTON=8
BS_VCENTER=3072
CALERT_SYSTEM=6
CAPSLOCK_ON=128
CA_LOG_FILTER=2
CA_NEGATIVE=1
CBM_CREATEDIB=2
CBM_INIT=4
CBN_CLOSEUP=8
CBN_DBLCLK=2
CBN_DROPDOWN=7
CBN_EDITCHANGE=5
CBN_EDITUPDATE=6
CBN_ERRSPACE=-1
CBN_KILLFOCUS=4
CBN_SELCHANGE=1
CBN_SELENDCANCEL=10
CBN_SELENDOK=9
CBN_SETFOCUS=3
CBR_110=110
CBR_115200=115200
CBR_1200=1200
CBR_128000=128000
CBR_14400=14400
CBR_19200=19200
CBR_2400=2400
CBR_256000=256000
CBR_300=300
CBR_38400=38400
CBR_4800=4800
CBR_56000=56000
CBR_57600=57600
CBR_600=600
CBR_9600=9600
CBS_AUTOHSCROLL=64
CBS_DISABLENOSCROLL=2048
CBS_DROPDOWN=2
CBS_DROPDOWNLIST=3
CBS_HASSTRINGS=512
CBS_LOWERCASE=16384
CBS_NOINTEGRALHEIGHT=1024
CBS_OEMCONVERT=128
CBS_OWNERDRAWFIXED=16
CBS_OWNERDRAWVARIABLE=32
CBS_SIMPLE=1
CBS_SORT=256
CBS_UPPERCASE=8192
CB_ADDSTRING=323
CB_DELETESTRING=324
CB_DIR=325
CB_ERR=-1
CB_ERRSPACE=-2
CB_FINDSTRING=332
CB_FINDSTRINGEXACT=344
CB_GETCOUNT=326
CB_GETCURSEL=327
CB_GETDROPPEDCONTROLRECT=338
CB_GETDROPPEDSTATE=343
CB_GETDROPPEDWIDTH=351
CB_GETEDITSEL=320
CB_GETEXTENDEDUI=342
CB_GETHORIZONTALEXTENT=349
CB_GETITEMDATA=336
CB_GETITEMHEIGHT=340
CB_GETLBTEXT=328
CB_GETLBTEXTLEN=329
CB_GETLOCALE=346
CB_GETTOPINDEX=347
CB_INITSTORAGE=353
CB_INSERTSTRING=330
CB_LIMITTEXT=321
CB_MSGMAX=354
CB_OKAY=0
CB_RESETCONTENT=331
CB_SELECTSTRING=333
CB_SETCURSEL=334
CB_SETDROPPEDWIDTH=352
CB_SETEDITSEL=322
CB_SETEXTENDEDUI=341
CB_SETHORIZONTALEXTENT=350
CB_SETITEMDATA=337
CB_SETITEMHEIGHT=339
CB_SETLOCALE=345
CB_SETTOPINDEX=348
CB_SHOWDROPDOWN=335
CCHDEVICENAME=32
CCHFORMNAME=32
CCHILDREN_SCROLLBAR=5
CCHILDREN_TITLEBAR=5
CC_ANYCOLOR=256
CC_CHORD=4
CC_CIRCLES=1
CC_ELLIPSES=8
CC_ENABLEHOOK=16
CC_ENABLETEMPLATE=32
CC_ENABLETEMPLATEHANDLE=64
CC_FULLOPEN=2
CC_INTERIORS=128
CC_NONE=0
CC_PIE=2
CC_PREVENTFULLOPEN=4
CC_RGBINIT=1
CC_ROUNDRECT=256
CC_SHOWHELP=8
CC_SOLIDCOLOR=128
CC_STYLED=32
CC_WIDE=16
CC_WIDESTYLED=64
CDM_FIRST=1124
CDM_GETFILEPATH=1125
CDM_GETFOLDERIDLIST=1127
CDM_GETFOLDERPATH=1126
CDM_GETSPEC=1124
CDM_HIDECONTROL=1129
CDM_LAST=1224
CDM_SETCONTROLTEXT=1128
CDM_SETDEFEXT=1130
CDN_FILEOK=-606
CDN_FIRST=-601
CDN_FOLDERCHANGE=-603
CDN_HELP=-605
CDN_INCLUDEITEM=-608
CDN_INITDONE=-601
CDN_LAST=-699
CDN_SELCHANGE=-602
CDN_SHAREVIOLATION=-604
CDN_TYPECHANGE=-607
CDS_FULLSCREEN=4
CDS_GLOBAL=8
CDS_NORESET=268435456
CDS_RESET=1073741824
CDS_SETRECT=536870912
CDS_SET_PRIMARY=16
CDS_TEST=2
CDS_UPDATEREGISTRY=1
CD_LBSELADD=2
CD_LBSELCHANGE=0
CD_LBSELNOITEMS=-1
CD_LBSELSUB=1
CFE_AUTOCOLOR=1073741824
CFE_BOLD=1
CFE_ITALIC=2
CFE_PROTECTED=16
CFE_STRIKEOUT=8
CFE_UNDERLINE=4
CFM_BOLD=1
CFM_CHARSET=134217728
CFM_COLOR=1073741824
CFM_FACE=536870912
CFM_ITALIC=2
CFM_OFFSET=268435456
CFM_PROTECTED=16
CFM_SIZE=-2147483648
CFM_STRIKEOUT=8
CFM_UNDERLINE=4
CF_ANSIONLY=1024
CF_APPLY=512
CF_BITMAP=2
CF_BOTH=3
CF_DIB=8
CF_DIBV5=17
CF_DIF=5
CF_DSPBITMAP=130
CF_DSPENHMETAFILE=142
CF_DSPMETAFILEPICT=131
CF_DSPTEXT=129
CF_EFFECTS=256
CF_ENABLEHOOK=8
CF_ENABLETEMPLATE=16
CF_ENABLETEMPLATEHANDLE=32
CF_ENHMETAFILE=14
CF_FIXEDPITCHONLY=16384
CF_FORCEFONTEXIST=65536
CF_GDIOBJFIRST=768
CF_GDIOBJLAST=1023
CF_HDROP=15
CF_INITTOLOGFONTSTRUCT=64
CF_LIMITSIZE=8192
CF_LOCALE=16
CF_MAX=18
CF_METAFILEPICT=3
CF_NOFACESEL=524288
CF_NOOEMFONTS=2048
CF_NOSCRIPTSEL=8388608
CF_NOSIMULATIONS=4096
CF_NOSIZESEL=2097152
CF_NOSTYLESEL=1048576
CF_NOVECTORFONTS=2048
CF_NOVERTFONTS=16777216
CF_OEMTEXT=7
CF_OWNERDISPLAY=128
CF_PALETTE=9
CF_PENDATA=10
CF_PRINTERFONTS=2
CF_PRIVATEFIRST=512
CF_PRIVATELAST=767
CF_RETEXTOBJ="RichEdit Text and Objects"
CF_RIFF=11
CF_RTF="Rich Text Format"
CF_RTFNOOBJS="Rich Text Format Without Objects"
CF_SCALABLEONLY=131072
CF_SCREENFONTS=1
CF_SCRIPTSONLY=1024
CF_SELECTSCRIPT=4194304
CF_SHOWHELP=4
CF_SYLK=4
CF_TEXT=1
CF_TIFF=6
CF_TTONLY=262144
CF_UNICODETEXT=13
CF_USESTYLE=128
CF_WAVE=12
CF_WYSIWYG=32768
CHILDID_SELF=0
CHINESEBIG5_CHARSET=136
CLEARTYPE_NATURAL_QUALITY=6
CLEARTYPE_QUALITY=5
CLIPCAPS=36
CLIP_CHARACTER_PRECIS=1
CLIP_DEFAULT_PRECIS=0
CLIP_EMBEDDED=128
CLIP_LH_ANGLES=16
CLIP_MASK=15
CLIP_STROKE_PRECIS=2
CLIP_TO_PATH=4097
CLIP_TT_ALWAYS=32
CLOSECHANNEL=4112
CLR_INVALID=-1
COLORMGMTCAPS=121
COLORONCOLOR=3
COLORRES=108
COLOR_3DDKSHADOW=21
COLOR_3DFACE=15
COLOR_3DHIGHLIGHT=20
COLOR_3DHILIGHT=20
COLOR_3DLIGHT=22
COLOR_3DSHADOW=16
COLOR_ACTIVEBORDER=10
COLOR_ACTIVECAPTION=2
COLOR_APPWORKSPACE=12
COLOR_BACKGROUND=1
COLOR_BTNFACE=15
COLOR_BTNHIGHLIGHT=20
COLOR_BTNHILIGHT=20
COLOR_BTNSHADOW=16
COLOR_BTNTEXT=18
COLOR_CAPTIONTEXT=9
COLOR_DESKTOP=1
COLOR_GRADIENTACTIVECAPTION=27
COLOR_GRADIENTINACTIVECAPTION=28
COLOR_GRAYTEXT=17
COLOR_HIGHLIGHT=13
COLOR_HIGHLIGHTTEXT=14
COLOR_HOTLIGHT=26
COLOR_INACTIVEBORDER=11
COLOR_INACTIVECAPTION=3
COLOR_INACTIVECAPTIONTEXT=19
COLOR_INFOBK=24
COLOR_INFOTEXT=23
COLOR_MENU=4
COLOR_MENUTEXT=7
COLOR_SCROLLBAR=0
COLOR_WINDOW=5
COLOR_WINDOWFRAME=6
COLOR_WINDOWTEXT=8
COMPLEXREGION=3
COMPRESSION_ENGINE_MAXIMUM=256
COMPRESSION_ENGINE_STANDARD=0
COMPRESSION_FORMAT_DEFAULT=1
COMPRESSION_FORMAT_LZNT1=2
COMPRESSION_FORMAT_NONE=0
CONTAINER_INHERIT_ACE=2
CONTEXT_ALPHA=131072
CONTEXT_CONTROL=1
CONTEXT_FLOATING_POINT=2
CONTEXT_FULL=7
CONTEXT_INTEGER=4
CONTEXT_PORTABLE_32BIT=1048576
CONTROL_C_EXIT=-1073741510
CP_NONE=0
CP_RECTANGLE=1
CP_REGION=2
CREATE_ALWAYS=2
CREATE_DEFAULT_ERROR_MODE=67108864
CREATE_NEW=1
CREATE_NEW_CONSOLE=16
CREATE_NEW_PROCESS_GROUP=512
CREATE_NO_WINDOW=134217728
CREATE_PROCESS_DEBUG_EVENT=3
CREATE_SEPARATE_WOW_VDM=2048
CREATE_SHARED_WOW_VDM=4096
CREATE_SUSPENDED=4
CREATE_THREAD_DEBUG_EVENT=2
CREATE_UNICODE_ENVIRONMENT=1024
CSOUND_SYSTEM=16
CS_BYTEALIGNCLIENT=4096
CS_BYTEALIGNWINDOW=8192
CS_CLASSDC=64
CS_DBLCLKS=8
CS_GLOBALCLASS=16384
CS_HREDRAW=2
CS_IME=65536
CS_NOCLOSE=512
CS_OWNDC=32
CS_PARENTDC=128
CS_SAVEBITS=2048
CS_VREDRAW=1
CTLCOLOR_BTN=3
CTLCOLOR_DLG=4
CTLCOLOR_EDIT=1
CTLCOLOR_LISTBOX=2
CTLCOLOR_MAX=7
CTLCOLOR_MSGBOX=0
CTLCOLOR_SCROLLBAR=5
CTLCOLOR_STATIC=6
CTRL_BREAK_EVENT=1
CTRL_CLOSE_EVENT=2
CTRL_C_EVENT=0
CTRL_LOGOFF_EVENT=5
CTRL_SHUTDOWN_EVENT=6
CUDR_NEGATIVECOORDS=8
CUDR_NOCLOSEGAPS=4
CUDR_NOPRIMARY=16
CUDR_NORESOLVEPOSITIONS=2
CUDR_NORMAL=0
CUDR_NOSNAPTOGRID=1
CURSOR_SHOWING=1
CURVECAPS=28
CWP_ALL=0
CWP_SKIPDISABLED=2
CWP_SKIPINVISIBLE=1
CWP_SKIPTRANSPARENT=4
CW_USEDEFAULT=-2147483648
ComputerNameDnsDomain=2
ComputerNameDnsFullyQualified=3
ComputerNameDnsHostname=1
ComputerNameNetBIOS=0
ComputerNamePhysicalDnsDomain=6
ComputerNamePhysicalDnsFullyQualified=7
ComputerNamePhysicalDnsHostname=5
ComputerNamePhysicalNetBIOS=4
DACL_SECURITY_INFORMATION=4
DBTF_MEDIA=1
DBTF_NET=2
DBTF_RESOURCE=1
DBTF_SLOWNET=4
DBTF_XPORT=2
DBT_APPYBEGIN=0
DBT_APPYEND=1
DBT_CONFIGCHANGECANCELED=25
DBT_CONFIGCHANGED=24
DBT_CONFIGMGAPI32=34
DBT_CONFIGMGPRIVATE=32767
DBT_CUSTOMEVENT=32774
DBT_DEVICEARRIVAL=32768
DBT_DEVICEQUERYREMOVE=32769
DBT_DEVICEQUERYREMOVEFAILED=32770
DBT_DEVICEREMOVECOMPLETE=32772
DBT_DEVICEREMOVEPENDING=32771
DBT_DEVICETYPESPECIFIC=32773
DBT_DEVNODES_CHANGED=7
DBT_DEVTYP_DEVICEINTERFACE=5
DBT_DEVTYP_DEVNODE=1
DBT_DEVTYP_HANDLE=6
DBT_DEVTYP_NET=4
DBT_DEVTYP_OEM=0
DBT_DEVTYP_PORT=3
DBT_DEVTYP_VOLUME=2
DBT_LOW_DISK_SPACE=72
DBT_MONITORCHANGE=27
DBT_NO_DISK_SPACE=71
DBT_QUERYCHANGECONFIG=23
DBT_SHELLLOGGEDON=32
DBT_USERDEFINED=65535
DBT_VOLLOCKLOCKFAILED=32835
DBT_VOLLOCKLOCKRELEASED=32837
DBT_VOLLOCKLOCKTAKEN=32834
DBT_VOLLOCKQUERYLOCK=32833
DBT_VOLLOCKQUERYUNLOCK=32836
DBT_VOLLOCKUNLOCKFAILED=32838
DBT_VPOWERDAPI=33024
DBT_VXDINITCOMPLETE=35
DBWF_LPARAMPOINTER=32768
DCBA_FACEDOWNCENTER=257
DCBA_FACEDOWNLEFT=258
DCBA_FACEDOWNNONE=256
DCBA_FACEDOWNRIGHT=259
DCBA_FACEUPCENTER=1
DCBA_FACEUPLEFT=2
DCBA_FACEUPNONE=0
DCBA_FACEUPRIGHT=3
DCB_ACCUMULATE=2
DCB_DIRTY=2
DCB_DISABLE=8
DCB_ENABLE=4
DCB_RESET=1
DCB_SET=3
DCTT_BITMAP=1
DCTT_DOWNLOAD=2
DCTT_DOWNLOAD_OUTLINE=8
DCTT_SUBDEV=4
DCX_CACHE=2
DCX_CLIPCHILDREN=8
DCX_CLIPSIBLINGS=16
DCX_EXCLUDERGN=64
DCX_EXCLUDEUPDATE=256
DCX_INTERSECTRGN=128
DCX_INTERSECTUPDATE=512
DCX_LOCKWINDOWUPDATE=1024
DCX_NORESETATTRS=4
DCX_PARENTCLIP=32
DCX_VALIDATE=2097152
DCX_WINDOW=1
DC_ACTIVE=1
DC_BINADJUST=19
DC_BINNAMES=12
DC_BINS=6
DC_BRUSH=18
DC_COLLATE=22
DC_COLORDEVICE=32
DC_COPIES=18
DC_DATATYPE_PRODUCED=21
DC_DRIVER=11
DC_DUPLEX=7
DC_EMF_COMPLIANT=20
DC_ENUMRESOLUTIONS=13
DC_EXTRA=9
DC_FIELDS=1
DC_FILEDEPENDENCIES=14
DC_GRADIENT=32
DC_HASDEFID=21323
DC_ICON=4
DC_INBUTTON=16
DC_MANUFACTURER=23
DC_MAXEXTENT=5
DC_MEDIAREADY=29
DC_MEDIATYPENAMES=34
DC_MEDIATYPES=35
DC_MINEXTENT=4
DC_MODEL=24
DC_NUP=33
DC_ORIENTATION=17
DC_PAPERNAMES=16
DC_PAPERS=2
DC_PAPERSIZE=3
DC_PEN=19
DC_PERSONALITY=25
DC_PRINTERMEM=28
DC_PRINTRATE=26
DC_PRINTRATEPPM=31
DC_PRINTRATEUNIT=27
DC_SIZE=8
DC_SMALLCAP=2
DC_STAPLE=30
DC_TEXT=8
DC_TRUETYPE=15
DC_VERSION=10
DDD_EXACT_MATCH_ON_REMOVE=4
DDD_RAW_TARGET_PATH=1
DDD_REMOVE_DEFINITION=2
DDL_ARCHIVE=32
DDL_DIRECTORY=16
DDL_DRIVES=16384
DDL_EXCLUSIVE=32768
DDL_HIDDEN=2
DDL_POSTMSGS=8192
DDL_READONLY=1
DDL_READWRITE=0
DDL_SYSTEM=4
DEBUG_ONLY_THIS_PROCESS=2
DEBUG_PROCESS=1
DEFAULT_CHARSET=1
DEFAULT_PALETTE=15
DEFAULT_PITCH=0
DEFAULT_QUALITY=0
DELETE=65536
DESKTOPHORZRES=118
DESKTOPVERTRES=117
DESKTOP_CREATEMENU=4
DESKTOP_CREATEWINDOW=2
DESKTOP_ENUMERATE=64
DESKTOP_HOOKCONTROL=8
DESKTOP_JOURNALPLAYBACK=32
DESKTOP_JOURNALRECORD=16
DESKTOP_READOBJECTS=1
DESKTOP_SWITCHDESKTOP=256
DESKTOP_WRITEOBJECTS=128
DETACHED_PROCESS=8
DEVICEDATA=19
DEVICE_DEFAULT_FONT=14
DEVICE_FONTTYPE=2
DEVICE_NOTIFY_SERVICE_HANDLE=1
DEVICE_NOTIFY_WINDOW_HANDLE=0
DFCS_ADJUSTRECT=8192
DFCS_BUTTON3STATE=8
DFCS_BUTTONCHECK=0
DFCS_BUTTONPUSH=16
DFCS_BUTTONRADIO=4
DFCS_BUTTONRADIOIMAGE=1
DFCS_BUTTONRADIOMASK=2
DFCS_CAPTIONCLOSE=0
DFCS_CAPTIONHELP=4
DFCS_CAPTIONMAX=2
DFCS_CAPTIONMIN=1
DFCS_CAPTIONRESTORE=3
DFCS_CHECKED=1024
DFCS_FLAT=16384
DFCS_HOT=4096
DFCS_INACTIVE=256
DFCS_MENUARROW=0
DFCS_MENUARROWRIGHT=4
DFCS_MENUBULLET=2
DFCS_MENUCHECK=1
DFCS_MONO=32768
DFCS_PUSHED=512
DFCS_SCROLLCOMBOBOX=5
DFCS_SCROLLDOWN=1
DFCS_SCROLLLEFT=2
DFCS_SCROLLRIGHT=3
DFCS_SCROLLSIZEGRIP=8
DFCS_SCROLLSIZEGRIPRIGHT=16
DFCS_SCROLLUP=0
DFCS_TRANSPARENT=2048
DFC_BUTTON=4
DFC_CAPTION=1
DFC_MENU=2
DFC_POPUPMENU=5
DFC_SCROLL=3
DF_ALLOWOTHERACCOUNTHOOK=1
DIB_PAL_COLORS=1
DIB_PAL_INDICES=2
DIB_PAL_LOGINDICES=4
DIB_PAL_PHYSINDICES=2
DIB_RGB_COLORS=0
DIFFERENCE=11
DISPLAY_DEVICE_ATTACHED_TO_DESKTOP=1
DISPLAY_DEVICE_DISCONNECT=33554432
DISPLAY_DEVICE_MIRRORING_DRIVER=8
DISPLAY_DEVICE_MODESPRUNED=134217728
DISPLAY_DEVICE_MULTI_DRIVER=2
DISPLAY_DEVICE_PRIMARY_DEVICE=4
DISPLAY_DEVICE_REMOTE=67108864
DISPLAY_DEVICE_REMOVABLE=32
DISPLAY_DEVICE_VGA_COMPATIBLE=16
DISP_CHANGE_BADDUALVIEW=-6
DISP_CHANGE_BADFLAGS=-4
DISP_CHANGE_BADMODE=-2
DISP_CHANGE_BADPARAM=-5
DISP_CHANGE_FAILED=-1
DISP_CHANGE_NOTUPDATED=-3
DISP_CHANGE_RESTART=1
DISP_CHANGE_SUCCESSFUL=0
DI_COMPAT=4
DI_DEFAULTSIZE=8
DI_IMAGE=2
DI_MASK=1
DI_NORMAL=3
DKGRAY_BRUSH=3
DLGC_BUTTON=8192
DLGC_DEFPUSHBUTTON=16
DLGC_HASSETSEL=8
DLGC_RADIOBUTTON=64
DLGC_STATIC=256
DLGC_UNDEFPUSHBUTTON=32
DLGC_WANTALLKEYS=4
DLGC_WANTARROWS=1
DLGC_WANTCHARS=128
DLGC_WANTMESSAGE=4
DLGC_WANTTAB=2
DLGWINDOWEXTRA=30
DLL_PROCESS_ATTACH=1
DLL_PROCESS_DETACH=0
DLL_THREAD_ATTACH=2
DLL_THREAD_DETACH=3
DMBIN_AUTO=7
DMBIN_CASSETTE=14
DMBIN_ENVELOPE=5
DMBIN_ENVMANUAL=6
DMBIN_FORMSOURCE=15
DMBIN_LARGECAPACITY=11
DMBIN_LARGEFMT=10
DMBIN_LAST=15
DMBIN_LOWER=2
DMBIN_MANUAL=4
DMBIN_MIDDLE=3
DMBIN_ONLYONE=1
DMBIN_SMALLFMT=9
DMBIN_TRACTOR=8
DMBIN_UPPER=1
DMBIN_USER=256
DMCOLLATE_FALSE=0
DMCOLLATE_TRUE=1
DMCOLOR_COLOR=2
DMCOLOR_MONOCHROME=1
DMDFO_CENTER=2
DMDFO_DEFAULT=0
DMDFO_STRETCH=1
DMDITHER_COARSE=2
DMDITHER_ERRORDIFFUSION=5
DMDITHER_FINE=3
DMDITHER_GRAYSCALE=10
DMDITHER_LINEART=4
DMDITHER_NONE=1
DMDITHER_RESERVED6=6
DMDITHER_RESERVED7=7
DMDITHER_RESERVED8=8
DMDITHER_RESERVED9=9
DMDITHER_USER=256
DMDO_180=2
DMDO_270=3
DMDO_90=1
DMDO_DEFAULT=0
DMDUP_HORIZONTAL=3
DMDUP_SIMPLEX=1
DMDUP_VERTICAL=2
DMICMMETHOD_DEVICE=4
DMICMMETHOD_DRIVER=3
DMICMMETHOD_NONE=1
DMICMMETHOD_SYSTEM=2
DMICMMETHOD_USER=256
DMICM_ABS_COLORIMETRIC=4
DMICM_COLORIMETRIC=3
DMICM_CONTRAST=2
DMICM_SATURATE=1
DMICM_USER=256
DMMEDIA_GLOSSY=3
DMMEDIA_STANDARD=1
DMMEDIA_TRANSPARENCY=2
DMMEDIA_USER=256
DMNUP_ONEUP=2
DMNUP_SYSTEM=1
DMORIENT_LANDSCAPE=2
DMORIENT_PORTRAIT=1
DMPAPER_10X11=45
DMPAPER_10X14=16
DMPAPER_11X17=17
DMPAPER_12X11=90
DMPAPER_15X11=46
DMPAPER_9X11=44
DMPAPER_A2=66
DMPAPER_A3=8
DMPAPER_A3_EXTRA=63
DMPAPER_A3_EXTRA_TRANSVERSE=68
DMPAPER_A3_ROTATED=76
DMPAPER_A3_TRANSVERSE=67
DMPAPER_A4=9
DMPAPER_A4SMALL=10
DMPAPER_A4_EXTRA=53
DMPAPER_A4_PLUS=60
DMPAPER_A4_ROTATED=77
DMPAPER_A4_TRANSVERSE=55
DMPAPER_A5=11
DMPAPER_A5_EXTRA=64
DMPAPER_A5_ROTATED=78
DMPAPER_A5_TRANSVERSE=61
DMPAPER_A6=70
DMPAPER_A6_ROTATED=83
DMPAPER_A_PLUS=57
DMPAPER_B4=12
DMPAPER_B4_JIS_ROTATED=79
DMPAPER_B5=13
DMPAPER_B5_EXTRA=65
DMPAPER_B5_JIS_ROTATED=80
DMPAPER_B5_TRANSVERSE=62
DMPAPER_B6_JIS=88
DMPAPER_B6_JIS_ROTATED=89
DMPAPER_B_PLUS=58
DMPAPER_CSHEET=24
DMPAPER_DBL_JAPANESE_POSTCARD=69
DMPAPER_DBL_JAPANESE_POSTCARD_ROTATED=82
DMPAPER_DSHEET=25
DMPAPER_ENV_10=20
DMPAPER_ENV_11=21
DMPAPER_ENV_12=22
DMPAPER_ENV_14=23
DMPAPER_ENV_9=19
DMPAPER_ENV_B4=33
DMPAPER_ENV_B5=34
DMPAPER_ENV_B6=35
DMPAPER_ENV_C3=29
DMPAPER_ENV_C4=30
DMPAPER_ENV_C5=28
DMPAPER_ENV_C6=31
DMPAPER_ENV_C65=32
DMPAPER_ENV_DL=27
DMPAPER_ENV_INVITE=47
DMPAPER_ENV_ITALY=36
DMPAPER_ENV_MONARCH=37
DMPAPER_ENV_PERSONAL=38
DMPAPER_ESHEET=26
DMPAPER_EXECUTIVE=7
DMPAPER_FANFOLD_LGL_GERMAN=41
DMPAPER_FANFOLD_STD_GERMAN=40
DMPAPER_FANFOLD_US=39
DMPAPER_FOLIO=14
DMPAPER_ISO_B4=42
DMPAPER_JAPANESE_POSTCARD=43
DMPAPER_JAPANESE_POSTCARD_ROTATED=81
DMPAPER_JENV_CHOU3=73
DMPAPER_JENV_CHOU3_ROTATED=86
DMPAPER_JENV_CHOU4=74
DMPAPER_JENV_CHOU4_ROTATED=87
DMPAPER_JENV_KAKU2=71
DMPAPER_JENV_KAKU2_ROTATED=84
DMPAPER_JENV_KAKU3=72
DMPAPER_JENV_KAKU3_ROTATED=85
DMPAPER_JENV_YOU4=91
DMPAPER_JENV_YOU4_ROTATED=92
DMPAPER_LAST=118
DMPAPER_LEDGER=4
DMPAPER_LEGAL=5
DMPAPER_LEGAL_EXTRA=51
DMPAPER_LETTER=1
DMPAPER_LETTERSMALL=2
DMPAPER_LETTER_EXTRA=50
DMPAPER_LETTER_EXTRA_TRANSVERSE=56
DMPAPER_LETTER_PLUS=59
DMPAPER_LETTER_ROTATED=75
DMPAPER_LETTER_TRANSVERSE=54
DMPAPER_NOTE=18
DMPAPER_P16K=93
DMPAPER_P16K_ROTATED=106
DMPAPER_P32K=94
DMPAPER_P32KBIG=95
DMPAPER_P32KBIG_ROTATED=108
DMPAPER_P32K_ROTATED=107
DMPAPER_PENV_1=96
DMPAPER_PENV_10=105
DMPAPER_PENV_10_ROTATED=118
DMPAPER_PENV_1_ROTATED=109
DMPAPER_PENV_2=97
DMPAPER_PENV_2_ROTATED=110
DMPAPER_PENV_3=98
DMPAPER_PENV_3_ROTATED=111
DMPAPER_PENV_4=99
DMPAPER_PENV_4_ROTATED=112
DMPAPER_PENV_5=100
DMPAPER_PENV_5_ROTATED=113
DMPAPER_PENV_6=101
DMPAPER_PENV_6_ROTATED=114
DMPAPER_PENV_7=102
DMPAPER_PENV_7_ROTATED=115
DMPAPER_PENV_8=103
DMPAPER_PENV_8_ROTATED=116
DMPAPER_PENV_9=104
DMPAPER_PENV_9_ROTATED=117
DMPAPER_QUARTO=15
DMPAPER_RESERVED_48=48
DMPAPER_RESERVED_49=49
DMPAPER_STATEMENT=6
DMPAPER_TABLOID=3
DMPAPER_TABLOID_EXTRA=52
DMPAPER_USER=256
DMRES_DRAFT=-1
DMRES_HIGH=-4
DMRES_LOW=-2
DMRES_MEDIUM=-3
DMTT_BITMAP=1
DMTT_DOWNLOAD=2
DMTT_DOWNLOAD_OUTLINE=4
DMTT_SUBDEV=3
DM_BITSPERPEL=262144
DM_COLLATE=32768
DM_COLOR=2048
DM_COPIES=256
DM_COPY=2
DM_DEFAULTSOURCE=512
DM_DISPLAYFIXEDOUTPUT=536870912
DM_DISPLAYFLAGS=2097152
DM_DISPLAYFREQUENCY=4194304
DM_DISPLAYORIENTATION=128
DM_DITHERTYPE=67108864
DM_DUPLEX=4096
DM_FORMNAME=65536
DM_GETDEFID=1024
DM_GRAYSCALE=1
DM_ICMINTENT=16777216
DM_ICMMETHOD=8388608
DM_INTERLACED=2
DM_IN_BUFFER=8
DM_IN_PROMPT=4
DM_LOGPIXELS=131072
DM_MEDIATYPE=33554432
DM_MODIFY=8
DM_NUP=64
DM_ORIENTATION=1
DM_OUT_BUFFER=2
DM_OUT_DEFAULT=1
DM_PANNINGHEIGHT=268435456
DM_PANNINGWIDTH=134217728
DM_PAPERLENGTH=4
DM_PAPERSIZE=2
DM_PAPERWIDTH=8
DM_PELSHEIGHT=1048576
DM_PELSWIDTH=524288
DM_POSITION=32
DM_PRINTQUALITY=1024
DM_PROMPT=4
DM_REPOSITION=1026
DM_SCALE=16
DM_SETDEFID=1025
DM_SPECVERSION=800
DM_TTOPTION=16384
DM_UPDATE=1
DM_YRESOLUTION=8192
DN_DEFAULTPRN=1
DOF_DIRECTORY=32771
DOF_DOCUMENT=32770
DOF_EXECUTABLE=32769
DOF_MULTIPLE=32772
DOF_PROGMAN=1
DOF_SHELLDATA=2
DOMAIN_ALIAS_RID_ACCOUNT_OPS=548
DOMAIN_ALIAS_RID_ADMINS=544
DOMAIN_ALIAS_RID_BACKUP_OPS=551
DOMAIN_ALIAS_RID_GUESTS=546
DOMAIN_ALIAS_RID_POWER_USERS=547
DOMAIN_ALIAS_RID_PRINT_OPS=550
DOMAIN_ALIAS_RID_REPLICATOR=552
DOMAIN_ALIAS_RID_SYSTEM_OPS=549
DOMAIN_ALIAS_RID_USERS=545
DOMAIN_GROUP_RID_ADMINS=512
DOMAIN_GROUP_RID_GUESTS=514
DOMAIN_GROUP_RID_USERS=513
DOMAIN_USER_RID_ADMIN=500
DOMAIN_USER_RID_GUEST=501
DONT_RESOLVE_DLL_REFERENCES=1
DOUBLE_CLICK=2
DOWNLOADFACE=514
DOWNLOADHEADER=4111
DO_DROPFILE=1162627398
DO_PRINTFILE=1414419024
DRAFTMODE=7
DRAFT_QUALITY=1
DRAWPATTERNRECT=25
DRIVERVERSION=0
DRIVE_CDROM=5
DRIVE_FIXED=3
DRIVE_NO_ROOT_DIR=1
DRIVE_RAMDISK=6
DRIVE_REMOTE=4
DRIVE_REMOVABLE=2
DRIVE_UNKNOWN=0
DSIG_FONTTYPE=262144
DSS_DISABLED=32
DSS_MONO=128
DSS_NORMAL=0
DSS_RIGHT=32768
DSS_UNION=16
DSTINVERT=5570569
DST_BITMAP=4
DST_COMPLEX=0
DST_ICON=3
DST_PREFIXTEXT=2
DST_TEXT=1
DS_3DLOOK=4
DS_ABSALIGN=1
DS_CENTER=2048
DS_CENTERMOUSE=4096
DS_CONTEXTHELP=8192
DS_CONTROL=1024
DS_FIXEDSYS=8
DS_LOCALEDIT=32
DS_MODALFRAME=128
DS_NOFAILCREATE=16
DS_NOIDLEMSG=256
DS_SETFONT=64
DS_SETFOREGROUND=512
DS_SYSMODAL=2
DTR_CONTROL_DISABLE=0
DTR_CONTROL_ENABLE=1
DTR_CONTROL_HANDSHAKE=2
DT_BOTTOM=8
DT_CALCRECT=1024
DT_CENTER=1
DT_CHARSTREAM=4
DT_DISPFILE=6
DT_EDITCONTROL=8192
DT_END_ELLIPSIS=32768
DT_EXPANDTABS=64
DT_EXTERNALLEADING=512
DT_INTERNAL=4096
DT_LEFT=0
DT_METAFILE=5
DT_MODIFYSTRING=65536
DT_NOCLIP=256
DT_NOPREFIX=2048
DT_PATH_ELLIPSIS=16384
DT_PLOTTER=0
DT_RASCAMERA=3
DT_RASDISPLAY=1
DT_RASPRINTER=2
DT_RIGHT=2
DT_RTLREADING=131072
DT_SINGLELINE=32
DT_TABSTOP=128
DT_TOP=0
DT_VCENTER=4
DT_WORDBREAK=16
DT_WORD_ELLIPSIS=262144
DUPLICATE_CLOSE_SOURCE=1
DUPLICATE_SAME_ACCESS=2
DWL_DLGPROC=4
DWL_MSGRESULT=0
DWL_USER=8
EASTEUROPE_CHARSET=238
ECOOP_AND=3
ECOOP_OR=2
ECOOP_SET=1
ECOOP_XOR=4
ECO_AUTOHSCROLL=128
ECO_AUTOVSCROLL=64
ECO_AUTOWORDSELECTION=1
ECO_NOHIDESEL=256
ECO_READONLY=2048
ECO_SAVESEL=32768
ECO_SELECTIONBAR=16777216
ECO_VERTICAL=4194304
ECO_WANTRETURN=4096
EC_LEFTMARGIN=1
EC_RIGHTMARGIN=2
EC_USEFONTINFO=65535
EDGE_BUMP=9
EDGE_ETCHED=6
EDGE_RAISED=5
EDGE_SUNKEN=10
EIMES_CANCELCOMPSTRINFOCUS=2
EIMES_COMPLETECOMPSTRKILLFOCUS=4
EIMES_GETCOMPSTRATONCE=1
ELF_CULTURE_LATIN=0
ELF_VENDOR_SIZE=4
ELF_VERSION=0
EMR_ABORTPATH=68
EMR_ANGLEARC=41
EMR_ARC=45
EMR_ARCTO=55
EMR_BEGINPATH=59
EMR_BITBLT=76
EMR_CHORD=46
EMR_CLOSEFIGURE=61
EMR_CREATEBRUSHINDIRECT=39
EMR_CREATEDIBPATTERNBRUSHPT=94
EMR_CREATEMONOBRUSH=93
EMR_CREATEPALETTE=49
EMR_CREATEPEN=38
EMR_DELETEOBJECT=40
EMR_ELLIPSE=42
EMR_ENDPATH=60
EMR_EOF=14
EMR_EXCLUDECLIPRECT=29
EMR_EXTCREATEFONTINDIRECTW=82
EMR_EXTCREATEPEN=95
EMR_EXTFLOODFILL=53
EMR_EXTSELECTCLIPRGN=75
EMR_EXTTEXTOUTA=83
EMR_EXTTEXTOUTW=84
EMR_FILLPATH=62
EMR_FILLRGN=71
EMR_FLATTENPATH=65
EMR_FRAMERGN=72
EMR_GDICOMMENT=70
EMR_HEADER=1
EMR_INTERSECTCLIPRECT=30
EMR_INVERTRGN=73
EMR_LINETO=54
EMR_MASKBLT=78
EMR_MAX=97
EMR_MIN=1
EMR_MODIFYWORLDTRANSFORM=36
EMR_MOVETOEX=27
EMR_OFFSETCLIPRGN=26
EMR_PAINTRGN=74
EMR_PIE=47
EMR_PLGBLT=79
EMR_POLYBEZIER=2
EMR_POLYBEZIER16=85
EMR_POLYBEZIERTO=5
EMR_POLYBEZIERTO16=88
EMR_POLYDRAW=56
EMR_POLYDRAW16=92
EMR_POLYGON=3
EMR_POLYGON16=86
EMR_POLYLINE=4
EMR_POLYLINE16=87
EMR_POLYLINETO=6
EMR_POLYLINETO16=89
EMR_POLYPOLYGON=8
EMR_POLYPOLYGON16=91
EMR_POLYPOLYLINE=7
EMR_POLYPOLYLINE16=90
EMR_POLYTEXTOUTA=96
EMR_POLYTEXTOUTW=97
EMR_REALIZEPALETTE=52
EMR_RECTANGLE=43
EMR_RESIZEPALETTE=51
EMR_RESTOREDC=34
EMR_ROUNDRECT=44
EMR_SAVEDC=33
EMR_SCALEVIEWPORTEXTEX=31
EMR_SCALEWINDOWEXTEX=32
EMR_SELECTCLIPPATH=67
EMR_SELECTOBJECT=37
EMR_SELECTPALETTE=48
EMR_SETARCDIRECTION=57
EMR_SETBKCOLOR=25
EMR_SETBKMODE=18
EMR_SETBRUSHORGEX=13
EMR_SETCOLORADJUSTMENT=23
EMR_SETDIBITSTODEVICE=80
EMR_SETMAPMODE=17
EMR_SETMAPPERFLAGS=16
EMR_SETMETARGN=28
EMR_SETMITERLIMIT=58
EMR_SETPALETTEENTRIES=50
EMR_SETPIXELV=15
EMR_SETPOLYFILLMODE=19
EMR_SETROP2=20
EMR_SETSTRETCHBLTMODE=21
EMR_SETTEXTALIGN=22
EMR_SETTEXTCOLOR=24
EMR_SETVIEWPORTEXTEX=11
EMR_SETVIEWPORTORGEX=12
EMR_SETWINDOWEXTEX=9
EMR_SETWINDOWORGEX=10
EMR_SETWORLDTRANSFORM=35
EMR_STRETCHBLT=77
EMR_STRETCHDIBITS=81
EMR_STROKEANDFILLPATH=63
EMR_STROKEPATH=64
EMR_WIDENPATH=66
EMSIS_COMPOSITIONSTRING=1
EM_CANUNDO=198
EM_CHARFROMPOS=215
EM_EMPTYUNDOBUFFER=205
EM_FMTLINES=200
EM_GETFIRSTVISIBLELINE=206
EM_GETHANDLE=189
EM_GETIMESTATUS=217
EM_GETLIMITTEXT=213
EM_GETLINE=196
EM_GETLINECOUNT=186
EM_GETMARGINS=212
EM_GETMODIFY=184
EM_GETPASSWORDCHAR=210
EM_GETRECT=178
EM_GETSEL=176
EM_GETTHUMB=190
EM_GETWORDBREAKPROC=209
EM_LIMITTEXT=197
EM_LINEFROMCHAR=201
EM_LINEINDEX=187
EM_LINELENGTH=193
EM_LINESCROLL=182
EM_POSFROMCHAR=214
EM_REPLACESEL=194
EM_SCROLL=181
EM_SCROLLCARET=183
EM_SETHANDLE=188
EM_SETIMESTATUS=216
EM_SETLIMITTEXT=197
EM_SETMARGINS=211
EM_SETMODIFY=185
EM_SETPASSWORDCHAR=204
EM_SETREADONLY=207
EM_SETRECT=179
EM_SETRECTNP=180
EM_SETSEL=177
EM_SETTABSTOPS=203
EM_SETWORDBREAKPROC=208
EM_UNDO=199
ENABLEDUPLEX=28
ENABLEPAIRKERNING=769
ENABLERELATIVEWIDTHS=768
ENCAPSULATED_POSTSCRIPT=4116
ENDDOC=11
ENDSESSION_LOGOFF=-2147483648
END_PATH=4098
ENHANCED_KEY=256
ENHMETA_SIGNATURE=1179469088
ENHMETA_STOCK_OBJECT=-2147483648
ENM_CHANGE=1
ENM_CORRECTTEXT=4194304
ENM_DROPFILES=1048576
ENM_IMECHANGE=8388608
ENM_KEYEVENTS=65536
ENM_MOUSEEVENTS=131072
ENM_NONE=0
ENM_PROTECTED=2097152
ENM_REQUESTRESIZE=262144
ENM_SCROLL=4
ENM_SELCHANGE=524288
ENM_UPDATE=2
ENUMPAPERBINS=31
ENUMPAPERMETRICS=34
ENUM_CURRENT_SETTINGS=-1
ENUM_REGISTRY_SETTINGS=-2
EN_CHANGE=768
EN_CORRECTTEXT=1797
EN_DROPFILES=1795
EN_ERRSPACE=1280
EN_HSCROLL=1537
EN_IMECHANGE=1799
EN_KILLFOCUS=512
EN_MAXTEXT=1281
EN_MSGFILTER=1792
EN_OLEOPFAILED=1801
EN_PROTECTED=1796
EN_REQUESTRESIZE=1793
EN_SAVECLIPBOARD=1800
EN_SELCHANGE=1794
EN_SETFOCUS=256
EN_STOPNOUNDO=1798
EN_UPDATE=1024
EN_VSCROLL=1538
EPSPRINTING=33
ERROR=0
ERROR_SEVERITY_ERROR=-1073741824
ERROR_SEVERITY_INFORMATIONAL=1073741824
ERROR_SEVERITY_SUCCESS=0
ERROR_SEVERITY_WARNING=-2147483648
ESB_DISABLE_BOTH=3
ESB_DISABLE_DOWN=2
ESB_DISABLE_LEFT=1
ESB_DISABLE_LTUP=1
ESB_DISABLE_RIGHT=2
ESB_DISABLE_RTDN=2
ESB_DISABLE_UP=1
ESB_ENABLE_BOTH=0
ES_AUTOHSCROLL=128
ES_AUTOVSCROLL=64
ES_CENTER=1
ES_DISABLENOSCROLL=8192
ES_EX_NOCALLOLEINIT=16777216
ES_LEFT=0
ES_LOWERCASE=16
ES_MULTILINE=4
ES_NOHIDESEL=256
ES_NOIME=524288
ES_NUMBER=8192
ES_OEMCONVERT=1024
ES_PASSWORD=32
ES_READONLY=2048
ES_RIGHT=2
ES_SAVESEL=32768
ES_SELECTIONBAR=16777216
ES_SELFIME=262144
ES_SUNKEN=16384
ES_UPPERCASE=8
ES_VERTICAL=4194304
ES_WANTRETURN=4096
ETO_CLIPPED=4
ETO_GRAYED=1
ETO_OPAQUE=2
EVENPARITY=2
EVENTLOG_AUDIT_FAILURE=16
EVENTLOG_AUDIT_SUCCESS=8
EVENTLOG_BACKWARDS_READ=8
EVENTLOG_END_ALL_PAIRED_EVENTS=4
EVENTLOG_END_PAIRED_EVENT=2
EVENTLOG_ERROR_TYPE=1
EVENTLOG_FORWARDS_READ=4
EVENTLOG_INFORMATION_TYPE=4
EVENTLOG_PAIRED_EVENT_ACTIVE=8
EVENTLOG_PAIRED_EVENT_INACTIVE=16
EVENTLOG_SEEK_READ=2
EVENTLOG_SEQUENTIAL_READ=1
EVENTLOG_START_PAIRED_EVENT=1
EVENTLOG_SUCCESS=0
EVENTLOG_WARNING_TYPE=2
EVENT_MAX=2147483647
EVENT_MIN=1
EVENT_MODIFY_STATE=2
EVENT_OBJECT_ACCELERATORCHANGE=32786
EVENT_OBJECT_CREATE=32768
EVENT_OBJECT_DEFACTIONCHANGE=32785
EVENT_OBJECT_DESCRIPTIONCHANGE=32781
EVENT_OBJECT_DESTROY=32769
EVENT_OBJECT_FOCUS=32773
EVENT_OBJECT_HELPCHANGE=32784
EVENT_OBJECT_HIDE=32771
EVENT_OBJECT_LOCATIONCHANGE=32779
EVENT_OBJECT_NAMECHANGE=32780
EVENT_OBJECT_PARENTCHANGE=32783
EVENT_OBJECT_REORDER=32772
EVENT_OBJECT_SELECTION=32774
EVENT_OBJECT_SELECTIONADD=32775
EVENT_OBJECT_SELECTIONREMOVE=32776
EVENT_OBJECT_SELECTIONWITHIN=32777
EVENT_OBJECT_SHOW=32770
EVENT_OBJECT_STATECHANGE=32778
EVENT_OBJECT_VALUECHANGE=32782
EVENT_SYSTEM_ALERT=2
EVENT_SYSTEM_CAPTUREEND=9
EVENT_SYSTEM_CAPTURESTART=8
EVENT_SYSTEM_CONTEXTHELPEND=13
EVENT_SYSTEM_CONTEXTHELPSTART=12
EVENT_SYSTEM_DIALOGEND=17
EVENT_SYSTEM_DIALOGSTART=16
EVENT_SYSTEM_DRAGDROPEND=15
EVENT_SYSTEM_DRAGDROPSTART=14
EVENT_SYSTEM_FOREGROUND=3
EVENT_SYSTEM_MENUEND=5
EVENT_SYSTEM_MENUPOPUPEND=7
EVENT_SYSTEM_MENUPOPUPSTART=6
EVENT_SYSTEM_MENUSTART=4
EVENT_SYSTEM_MINIMIZEEND=23
EVENT_SYSTEM_MINIMIZESTART=22
EVENT_SYSTEM_MOVESIZEEND=11
EVENT_SYSTEM_MOVESIZESTART=10
EVENT_SYSTEM_SCROLLINGEND=19
EVENT_SYSTEM_SCROLLINGSTART=18
EVENT_SYSTEM_SOUND=1
EVENT_SYSTEM_SWITCHEND=21
EVENT_SYSTEM_SWITCHSTART=20
EWX_FORCE=4
EWX_FORCEIFHUNG=16
EWX_LOGOFF=0
EWX_POWEROFF=8
EWX_REBOOT=2
EWX_SHUTDOWN=1
EXCEPTION_ACCESS_VIOLATION=-1073741819
EXCEPTION_ARRAY_BOUNDS_EXCEEDED=-1073741684
EXCEPTION_BREAKPOINT=-2147483645
EXCEPTION_DATATYPE_MISALIGNMENT=-2147483646
EXCEPTION_DEBUG_EVENT=1
EXCEPTION_FLT_DENORMAL_OPERAND=-1073741683
EXCEPTION_FLT_DIVIDE_BY_ZERO=-1073741682
EXCEPTION_FLT_INEXACT_RESULT=-1073741681
EXCEPTION_FLT_INVALID_OPERATION=-1073741680
EXCEPTION_FLT_OVERFLOW=-1073741679
EXCEPTION_FLT_STACK_CHECK=-1073741678
EXCEPTION_FLT_UNDERFLOW=-1073741677
EXCEPTION_GUARD_PAGE=-2147483647
EXCEPTION_ILLEGAL_INSTRUCTION=-1073741795
EXCEPTION_INT_DIVIDE_BY_ZERO=-1073741676
EXCEPTION_INT_OVERFLOW=-1073741675
EXCEPTION_INVALID_DISPOSITION=-1073741786
EXCEPTION_INVALID_HANDLE=-1073741816
EXCEPTION_IN_PAGE_ERROR=-1073741818
EXCEPTION_NONCONTINUABLE_EXCEPTION=-1073741787
EXCEPTION_PRIV_INSTRUCTION=-1073741674
EXCEPTION_SINGLE_STEP=-2147483644
EXCEPTION_STACK_OVERFLOW=-1073741571
EXIT_PROCESS_DEBUG_EVENT=5
EXIT_THREAD_DEBUG_EVENT=4
EXTTEXTOUT=512
EXT_DEVICE_CAPS=4099
FAILED_ACCESS_ACE_FLAG=128
FALSE=0
FALT=16
FCONTROL=8
FEATURESETTING_CUSTPAPER=3
FEATURESETTING_MIRROR=4
FEATURESETTING_NEGATIVE=5
FEATURESETTING_NUP=0
FEATURESETTING_OUTPUT=1
FEATURESETTING_PRIVATE_BEGIN=4096
FEATURESETTING_PRIVATE_END=8191
FEATURESETTING_PROTOCOL=6
FEATURESETTING_PSLEVEL=2
FE_FONTSMOOTHINGCLEARTYPE=2
FE_FONTSMOOTHINGDOCKING=32768
FE_FONTSMOOTHINGSTANDARD=1
FF_DECORATIVE=80
FF_DONTCARE=0
FF_MODERN=48
FF_ROMAN=16
FF_SCRIPT=64
FF_SWISS=32
FILE_ATTRIBUTE_ARCHIVE=32
FILE_ATTRIBUTE_ATOMIC_WRITE=512
FILE_ATTRIBUTE_COMPRESSED=2048
FILE_ATTRIBUTE_DEVICE=64
FILE_ATTRIBUTE_DIRECTORY=16
FILE_ATTRIBUTE_ENCRYPTED=16384
FILE_ATTRIBUTE_HIDDEN=2
FILE_ATTRIBUTE_NORMAL=128
FILE_ATTRIBUTE_NOT_CONTENT_INDEXED=8192
FILE_ATTRIBUTE_OFFLINE=4096
FILE_ATTRIBUTE_READONLY=1
FILE_ATTRIBUTE_REPARSE_POINT=1024
FILE_ATTRIBUTE_SPARSE_FILE=512
FILE_ATTRIBUTE_SYSTEM=4
FILE_ATTRIBUTE_TEMPORARY=256
FILE_ATTRIBUTE_VIRTUAL=65536
FILE_ATTRIBUTE_XACTION_WRITE=1024
FILE_BEGIN=0
FILE_CASE_PRESERVED_NAMES=2
FILE_CASE_SENSITIVE_SEARCH=1
FILE_CURRENT=1
FILE_END=2
FILE_FILE_COMPRESSION=16
FILE_FLAG_BACKUP_SEMANTICS=33554432
FILE_FLAG_DELETE_ON_CLOSE=67108864
FILE_FLAG_NO_BUFFERING=536870912
FILE_FLAG_OVERLAPPED=1073741824
FILE_FLAG_POSIX_SEMANTICS=16777216
FILE_FLAG_RANDOM_ACCESS=268435456
FILE_FLAG_SEQUENTIAL_SCAN=134217728
FILE_FLAG_WRITE_THROUGH=-2147483648
FILE_NAME_NORMALIZED=0
FILE_NAME_OPENED=8
FILE_NOTIFY_CHANGE_ATTRIBUTES=4
FILE_NOTIFY_CHANGE_DIR_NAME=2
FILE_NOTIFY_CHANGE_FILE_NAME=1
FILE_NOTIFY_CHANGE_LAST_WRITE=16
FILE_NOTIFY_CHANGE_SECURITY=256
FILE_NOTIFY_CHANGE_SIZE=8
FILE_PERSISTENT_ACLS=8
FILE_SHARE_DELETE=4
FILE_SHARE_READ=1
FILE_SHARE_WRITE=2
FILE_TYPE_CHAR=2
FILE_TYPE_DISK=1
FILE_TYPE_PIPE=3
FILE_TYPE_REMOTE=32768
FILE_TYPE_UNKNOWN=0
FILE_UNICODE_ON_DISK=4
FILE_VOLUME_IS_COMPRESSED=32768
FIXED_PITCH=1
FKF_AVAILABLE=2
FKF_CLICKON=64
FKF_CONFIRMHOTKEY=8
FKF_FILTERKEYSON=1
FKF_HOTKEYACTIVE=4
FKF_HOTKEYSOUND=16
FKF_INDICATOR=32
FLASHW_ALL=3
FLASHW_CAPTION=1
FLASHW_STOP=0
FLASHW_TIMER=4
FLASHW_TIMERNOFG=12
FLASHW_TRAY=2
FLOODFILLBORDER=0
FLOODFILLSURFACE=1
FLUSHOUTPUT=6
FNOINVERT=2
FONTMAPPER_MAX=10
FORMAT_MESSAGE_ALLOCATE_BUFFER=256
FORMAT_MESSAGE_ARGUMENT_ARRAY=8192
FORMAT_MESSAGE_FROM_HMODULE=2048
FORMAT_MESSAGE_FROM_STRING=1024
FORMAT_MESSAGE_FROM_SYSTEM=4096
FORMAT_MESSAGE_IGNORE_INSERTS=512
FORMAT_MESSAGE_MAX_WIDTH_MASK=255
FRAME_FPO=0
FRAME_TRAP=1
FRAME_TSS=2
FROM_LEFT_1ST_BUTTON_PRESSED=1
FROM_LEFT_2ND_BUTTON_PRESSED=4
FROM_LEFT_3RD_BUTTON_PRESSED=8
FROM_LEFT_4TH_BUTTON_PRESSED=16
FR_DIALOGTERM=64
FR_DOWN=1
FR_ENABLEHOOK=256
FR_ENABLETEMPLATE=512
FR_ENABLETEMPLATEHANDLE=8192
FR_FINDNEXT=8
FR_HIDEMATCHCASE=32768
FR_HIDEUPDOWN=16384
FR_HIDEWHOLEWORD=65536
FR_MATCHCASE=4
FR_NOMATCHCASE=2048
FR_NOUPDOWN=1024
FR_NOWHOLEWORD=4096
FR_REPLACE=16
FR_REPLACEALL=32
FR_SHOWHELP=128
FR_WHOLEWORD=2
FSHIFT=4
FVIRTKEY=1
FW_BLACK=900
FW_BOLD=700
FW_DEMIBOLD=600
FW_DONTCARE=0
FW_EXTRABOLD=800
FW_EXTRALIGHT=200
FW_HEAVY=900
FW_LIGHT=300
FW_MEDIUM=500
FW_NORMAL=400
FW_REGULAR=400
FW_SEMIBOLD=600
FW_THIN=100
FW_ULTRABOLD=800
FW_ULTRALIGHT=200
GA_MAC=4
GA_MIC=1
GA_PARENT=1
GA_ROOT=2
GA_ROOTOWNER=3
GCL_CBCLSEXTRA=-20
GCL_CBWNDEXTRA=-18
GCL_HBRBACKGROUND=-10
GCL_HCURSOR=-12
GCL_HICON=-14
GCL_HICONSM=-34
GCL_HMODULE=-16
GCL_MENUNAME=-8
GCL_STYLE=-26
GCL_WNDPROC=-24
GCW_ATOM=-32
GDI_ERROR=-1
GENERIC_ALL=268435456
GENERIC_EXECUTE=536870912
GENERIC_READ=-2147483648
GENERIC_WRITE=1073741824
GETCOLORTABLE=5
GETDEVICEUNITS=42
GETEXTENDEDTEXTMETRICS=256
GETEXTENTTABLE=257
GETFACENAME=513
GETPAIRKERNTABLE=258
GETPENWIDTH=16
GETPHYSPAGESIZE=12
GETPRINTINGOFFSET=13
GETSCALINGFACTOR=14
GETSETPAPERBINS=29
GETSETPAPERMETRICS=35
GETSETPRINTORIENT=30
GETSETSCREENPARAMS=3072
GETTECHNOLGY=20
GETTECHNOLOGY=20
GETTRACKKERNTABLE=259
GETVECTORBRUSHSIZE=27
GETVECTORPENSIZE=26
GET_TAPE_DRIVE_INFORMATION=1
GET_TAPE_MEDIA_INFORMATION=0
GGO_BITMAP=1
GGO_METRICS=0
GGO_NATIVE=2
GHND=66
GMDI_GOINTOPOPUPS=2
GMDI_USEDISABLED=1
GMEM_DDESHARE=8192
GMEM_DISCARDABLE=256
GMEM_DISCARDED=16384
GMEM_FIXED=0
GMEM_INVALID_HANDLE=32768
GMEM_LOCKCOUNT=255
GMEM_LOWER=4096
GMEM_MODIFY=128
GMEM_MOVEABLE=2
GMEM_NOCOMPACT=16
GMEM_NODISCARD=32
GMEM_NOTIFY=16384
GMEM_NOT_BANKED=4096
GMEM_SHARE=8192
GMEM_VALID_FLAGS=32626
GMEM_ZEROINIT=64
GM_ADVANCED=2
GM_COMPATIBLE=1
GM_LAST=2
GPTR=64
GRADIENT_FILL_OP_FLAG=255
GRADIENT_FILL_RECT_H=0
GRADIENT_FILL_RECT_V=1
GRADIENT_FILL_TRIANGLE=2
GRAY_BRUSH=2
GREEK_CHARSET=161
GROUP_SECURITY_INFORMATION=2
GR_GDIOBJECTS=0
GR_USEROBJECTS=1
GUI_CARETBLINKING=1
GUI_INMENUMODE=4
GUI_INMOVESIZE=2
GUI_POPUPMENUMODE=16
GUI_SYSTEMMENUMODE=8
GWL_EXSTYLE=-20
GWL_HINSTANCE=-6
GWL_HWNDPARENT=-8
GWL_ID=-12
GWL_STYLE=-16
GWL_USERDATA=-21
GWL_WNDPROC=-4
GW_CHILD=5
GW_ENABLEDPOPUP=6
GW_HWNDFIRST=0
GW_HWNDLAST=1
GW_HWNDNEXT=2
GW_HWNDPREV=3
GW_MAX=6
GW_OWNER=4
HALFTONE=4
HANDLE_FLAG_INHERIT=1
HANDLE_FLAG_PROTECT_FROM_CLOSE=2
HANGEUL_CHARSET=129
HBMMENU_CALLBACK=-1
HBMMENU_MBAR_CLOSE=5
HBMMENU_MBAR_CLOSE_D=6
HBMMENU_MBAR_MINIMIZE=3
HBMMENU_MBAR_MINIMIZE_D=7
HBMMENU_MBAR_RESTORE=2
HBMMENU_POPUP_CLOSE=8
HBMMENU_POPUP_MAXIMIZE=10
HBMMENU_POPUP_MINIMIZE=11
HBMMENU_POPUP_RESTORE=9
HBMMENU_SYSTEM=1
HCBT_ACTIVATE=5
HCBT_CLICKSKIPPED=6
HCBT_CREATEWND=3
HCBT_DESTROYWND=4
HCBT_KEYSKIPPED=7
HCBT_MINMAX=1
HCBT_MOVESIZE=0
HCBT_QS=2
HCBT_SETFOCUS=9
HCBT_SYSCOMMAND=8
HCF_AVAILABLE=2
HCF_CONFIRMHOTKEY=8
HCF_HIGHCONTRASTON=1
HCF_HOTKEYACTIVE=4
HCF_HOTKEYAVAILABLE=64
HCF_HOTKEYSOUND=16
HCF_INDICATOR=32
HC_ACTION=0
HC_GETNEXT=1
HC_NOREM=3
HC_NOREMOVE=3
HC_SKIP=2
HC_SYSMODALOFF=5
HC_SYSMODALON=4
HEAP_DISABLE_COALESCE_ON_FREE=128
HEAP_FREE_CHECKING_ENABLED=64
HEAP_GENERATE_EXCEPTIONS=4
HEAP_GROWABLE=2
HEAP_NO_SERIALIZE=1
HEAP_REALLOC_IN_PLACE_ONLY=16
HEAP_TAIL_CHECKING_ENABLED=32
HEAP_ZERO_MEMORY=8
HEBREW_CHARSET=177
HELPINFO_MENUITEM=2
HELPINFO_WINDOW=1
HELP_COMMAND=258
HELP_CONTENTS=3
HELP_CONTEXT=1
HELP_CONTEXTMENU=10
HELP_CONTEXTPOPUP=8
HELP_FINDER=11
HELP_FORCEFILE=9
HELP_HELPONHELP=4
HELP_INDEX=3
HELP_KEY=257
HELP_MULTIKEY=513
HELP_PARTIALKEY=261
HELP_QUIT=2
HELP_SETCONTENTS=5
HELP_SETINDEX=5
HELP_SETPOPUP_POS=13
HELP_SETWINPOS=515
HELP_TCARD=32768
HELP_TCARD_DATA=16
HELP_TCARD_OTHER_CALLER=17
HELP_WM_HELP=12
HIDE_WINDOW=0
HIGH_PRIORITY_CLASS=128
HINSTANCE_ERROR=32
HKEY_CLASSES_ROOT=-2147483648
HKEY_CURRENT_CONFIG=-2147483643
HKEY_CURRENT_USER=-2147483647
HKEY_DYN_DATA=-2147483642
HKEY_LOCAL_MACHINE=-2147483646
HKEY_PERFORMANCE_DATA=-2147483644
HKEY_PERFORMANCE_NLSTEXT=-2147483552
HKEY_PERFORMANCE_TEXT=-2147483568
HKEY_USERS=-2147483645
HKL_NEXT=1
HKL_PREV=0
HOLLOW_BRUSH=5
HORZRES=8
HORZSIZE=4
HOVER_DEFAULT=-1
HSHELL_ACCESSIBILITYSTATE=11
HSHELL_ACTIVATESHELLWINDOW=3
HSHELL_GETMINRECT=5
HSHELL_LANGUAGE=8
HSHELL_REDRAW=6
HSHELL_TASKMAN=7
HSHELL_WINDOWACTIVATED=4
HSHELL_WINDOWCREATED=1
HSHELL_WINDOWDESTROYED=2
HS_API_MAX=25
HS_BDIAGONAL=3
HS_BDIAGONAL1=7
HS_CROSS=4
HS_DENSE1=9
HS_DENSE2=10
HS_DENSE3=11
HS_DENSE4=12
HS_DENSE5=13
HS_DENSE6=14
HS_DENSE7=15
HS_DENSE8=16
HS_DIAGCROSS=5
HS_DITHEREDBKCLR=24
HS_DITHEREDCLR=20
HS_DITHEREDTEXTCLR=22
HS_FDIAGONAL=2
HS_FDIAGONAL1=6
HS_HALFTONE=18
HS_HORIZONTAL=0
HS_NOSHADE=17
HS_SOLID=8
HS_SOLIDBKCLR=23
HS_SOLIDCLR=19
HS_SOLIDTEXTCLR=21
HS_VERTICAL=1
HTBORDER=18
HTBOTTOM=15
HTBOTTOMLEFT=16
HTBOTTOMRIGHT=17
HTCAPTION=2
HTCLIENT=1
HTCLOSE=20
HTERROR=-2
HTGROWBOX=4
HTHELP=21
HTHSCROLL=6
HTLEFT=10
HTMAXBUTTON=9
HTMENU=5
HTMINBUTTON=8
HTNOWHERE=0
HTOBJECT=19
HTREDUCE=8
HTRIGHT=11
HTSIZE=4
HTSIZEFIRST=10
HTSIZELAST=17
HTSYSMENU=3
HTTOP=12
HTTOPLEFT=13
HTTOPRIGHT=14
HTTRANSPARENT=-1
HTVSCROLL=7
HTZOOM=9
HWND_BOTTOM=1
HWND_BROADCAST=65535
HWND_DESKTOP=0
HWND_MESSAGE=-3
HWND_NOTOPMOST=-2
HWND_TOP=0
HWND_TOPMOST=-1
ICON_BIG=1
ICON_SMALL=0
IDABORT=3
IDANI_CAPTION=3
IDANI_CLOSE=2
IDANI_OPEN=1
IDCANCEL=2
IDCLOSE=8
IDC_APPSTARTING=32650
IDC_ARROW=32512
IDC_CROSS=32515
IDC_HAND=32649
IDC_HELP=32651
IDC_IBEAM=32513
IDC_ICON=32641
IDC_NO=32648
IDC_SIZE=32640
IDC_SIZEALL=32646
IDC_SIZENESW=32643
IDC_SIZENS=32645
IDC_SIZENWSE=32642
IDC_SIZEWE=32644
IDC_UPARROW=32516
IDC_WAIT=32514
IDHELP=9
IDHOT_SNAPDESKTOP=-2
IDHOT_SNAPWINDOW=-1
IDH_CANCEL=28444
IDH_GENERIC_HELP_BUTTON=28442
IDH_HELP=28445
IDH_MISSING_CONTEXT=28441
IDH_NO_HELP=28440
IDH_OK=28443
IDIGNORE=5
IDI_APPLICATION=32512
IDI_ASTERISK=32516
IDI_ERROR=32513
IDI_EXCLAMATION=32515
IDI_HAND=32513
IDI_INFORMATION=32516
IDI_QUESTION=32514
IDI_WARNING=32515
IDI_WINLOGO=32517
IDLE_PRIORITY_CLASS=64
IDNO=7
IDOK=1
IDRETRY=4
IDYES=6
ILLUMINANT_A=1
ILLUMINANT_B=2
ILLUMINANT_C=3
ILLUMINANT_D50=4
ILLUMINANT_D55=5
ILLUMINANT_D65=6
ILLUMINANT_D75=7
ILLUMINANT_DAYLIGHT=3
ILLUMINANT_DEVICE_DEFAULT=0
ILLUMINANT_F2=8
ILLUMINANT_FLUORESCENT=8
ILLUMINANT_MAX_INDEX=8
ILLUMINANT_NTSC=3
ILLUMINANT_TUNGSTEN=1
IMAGE_ARCHIVE_START_SIZE=8
IMAGE_BITMAP=0
IMAGE_COMDAT_SELECT_ANY=2
IMAGE_COMDAT_SELECT_ASSOCIATIVE=5
IMAGE_COMDAT_SELECT_EXACT_MATCH=4
IMAGE_COMDAT_SELECT_NODUPLICATES=1
IMAGE_COMDAT_SELECT_SAME_SIZE=3
IMAGE_CURSOR=2
IMAGE_DEBUG_MISC_EXENAME=1
IMAGE_DEBUG_TYPE_CODEVIEW=2
IMAGE_DEBUG_TYPE_COFF=1
IMAGE_DEBUG_TYPE_EXCEPTION=5
IMAGE_DEBUG_TYPE_FIXUP=6
IMAGE_DEBUG_TYPE_FPO=3
IMAGE_DEBUG_TYPE_MISC=4
IMAGE_DEBUG_TYPE_OMAP_FROM_SRC=8
IMAGE_DEBUG_TYPE_OMAP_TO_SRC=7
IMAGE_DEBUG_TYPE_UNKNOWN=0
IMAGE_ENHMETAFILE=3
IMAGE_FILE_MACHINE_UNKNOWN=0
IMAGE_ICON=1
IMAGE_NT_OPTIONAL_HDR_MAGIC=267
IMAGE_NUMBEROF_DIRECTORY_ENTRIES=16
IMAGE_ORDINAL_FLAG=-2147483648
IMAGE_REL_ALPHA_ABSOLUTE=0
IMAGE_REL_ALPHA_BRADDR=7
IMAGE_REL_ALPHA_GPDISP=6
IMAGE_REL_ALPHA_GPREL32=3
IMAGE_REL_ALPHA_HINT=8
IMAGE_REL_ALPHA_INLINE_REFLONG=9
IMAGE_REL_ALPHA_LITERAL=4
IMAGE_REL_ALPHA_LITUSE=5
IMAGE_REL_ALPHA_MATCH=13
IMAGE_REL_ALPHA_PAIR=12
IMAGE_REL_ALPHA_REFHI=10
IMAGE_REL_ALPHA_REFLO=11
IMAGE_REL_ALPHA_REFLONG=1
IMAGE_REL_ALPHA_REFLONGNB=16
IMAGE_REL_ALPHA_REFQUAD=2
IMAGE_REL_ALPHA_SECREL=15
IMAGE_REL_ALPHA_SECTION=14
IMAGE_REL_BASED_ABSOLUTE=0
IMAGE_REL_BASED_HIGH=1
IMAGE_REL_BASED_HIGHADJ=4
IMAGE_REL_BASED_HIGHLOW=3
IMAGE_REL_BASED_LOW=2
IMAGE_REL_BASED_MIPS_JMPADDR=5
IMAGE_REL_I386_SECREL=11
IMAGE_REL_I386_SECTION=10
IMAGE_REL_MIPS_GPREL=6
IMAGE_REL_MIPS_JMPADDR=3
IMAGE_REL_MIPS_LITERAL=7
IMAGE_REL_MIPS_PAIR=37
IMAGE_REL_MIPS_REFHALF=1
IMAGE_REL_MIPS_REFHI=4
IMAGE_REL_MIPS_REFLO=5
IMAGE_REL_MIPS_REFWORD=2
IMAGE_REL_MIPS_REFWORDNB=34
IMAGE_REL_MIPS_SECREL=11
IMAGE_REL_MIPS_SECTION=10
IMAGE_RESOURCE_DATA_IS_DIRECTORY=-2147483648
IMAGE_RESOURCE_NAME_IS_STRING=-2147483648
IMAGE_ROM_OPTIONAL_HDR_MAGIC=263
IMAGE_SEPARATE_DEBUG_SIGNATURE=18756
IMAGE_SIZEOF_ARCHIVE_MEMBER_HDR=60
IMAGE_SIZEOF_AUX_SYMBOL=18
IMAGE_SIZEOF_BASE_RELOCATION=8
IMAGE_SIZEOF_FILE_HEADER=20
IMAGE_SIZEOF_LINENUMBER=6
IMAGE_SIZEOF_NT_OPTIONAL_HEADER=224
IMAGE_SIZEOF_RELOCATION=10
IMAGE_SIZEOF_ROM_OPTIONAL_HEADER=56
IMAGE_SIZEOF_SECTION_HEADER=40
IMAGE_SIZEOF_SHORT_NAME=8
IMAGE_SIZEOF_STD_OPTIONAL_HEADER=28
IMAGE_SIZEOF_SYMBOL=18
IMAGE_SYM_CLASS_ARGUMENT=9
IMAGE_SYM_CLASS_AUTOMATIC=1
IMAGE_SYM_CLASS_BIT_FIELD=18
IMAGE_SYM_CLASS_BLOCK=100
IMAGE_SYM_CLASS_END_OF_STRUCT=102
IMAGE_SYM_CLASS_ENUM_TAG=15
IMAGE_SYM_CLASS_EXTERNAL=2
IMAGE_SYM_CLASS_EXTERNAL_DEF=5
IMAGE_SYM_CLASS_FILE=103
IMAGE_SYM_CLASS_FUNCTION=101
IMAGE_SYM_CLASS_LABEL=6
IMAGE_SYM_CLASS_MEMBER_OF_ENUM=16
IMAGE_SYM_CLASS_MEMBER_OF_STRUCT=8
IMAGE_SYM_CLASS_MEMBER_OF_UNION=11
IMAGE_SYM_CLASS_NULL=0
IMAGE_SYM_CLASS_REGISTER=4
IMAGE_SYM_CLASS_REGISTER_PARAM=17
IMAGE_SYM_CLASS_SECTION=104
IMAGE_SYM_CLASS_STATIC=3
IMAGE_SYM_CLASS_STRUCT_TAG=10
IMAGE_SYM_CLASS_TYPE_DEFINITION=13
IMAGE_SYM_CLASS_UNDEFINED_LABEL=7
IMAGE_SYM_CLASS_UNDEFINED_STATIC=14
IMAGE_SYM_CLASS_UNION_TAG=12
IMAGE_SYM_CLASS_WEAK_EXTERNAL=105
IMAGE_WEAK_EXTERN_SEARCH_ALIAS=3
IMAGE_WEAK_EXTERN_SEARCH_LIBRARY=2
IMAGE_WEAK_EXTERN_SEARCH_NOLIBRARY=1
IMC_CLOSESTATUSWINDOW=33
IMC_GETCANDIDATEPOS=7
IMC_GETCOMPOSITIONFONT=9
IMC_GETCOMPOSITIONWINDOW=11
IMC_GETSTATUSWINDOWPOS=15
IMC_OPENSTATUSWINDOW=34
IMC_SETCANDIDATEPOS=8
IMC_SETCOMPOSITIONFONT=10
IMC_SETCOMPOSITIONWINDOW=12
IMC_SETSTATUSWINDOWPOS=16
IMN_CHANGECANDIDATE=3
IMN_CLOSECANDIDATE=4
IMN_CLOSESTATUSWINDOW=1
IMN_GUIDELINE=13
IMN_OPENCANDIDATE=5
IMN_OPENSTATUSWINDOW=2
IMN_PRIVATE=14
IMN_SETCANDIDATEPOS=9
IMN_SETCOMPOSITIONFONT=10
IMN_SETCOMPOSITIONWINDOW=11
IMN_SETCONVERSIONMODE=6
IMN_SETOPENSTATUS=8
IMN_SETSENTENCEMODE=7
IMN_SETSTATUSWINDOWPOS=12
INDEXID_CONTAINER=0
INDEXID_OBJECT=0
INHERIT_ONLY_ACE=8
INPUT_HARDWARE=2
INPUT_KEYBOARD=1
INPUT_MOUSE=0
IO_COMPLETION_MODIFY_STATE=2
ISMEX_CALLBACK=4
ISMEX_NOSEND=0
ISMEX_NOTIFY=2
ISMEX_REPLIED=8
ISMEX_SEND=1
IS_TEXT_UNICODE_ASCII16=1
IS_TEXT_UNICODE_CONTROLS=4
IS_TEXT_UNICODE_DBCS_LEADBYTE=1024
IS_TEXT_UNICODE_ILLEGAL_CHARS=256
IS_TEXT_UNICODE_NOT_ASCII_MASK=61440
IS_TEXT_UNICODE_NOT_UNICODE_MASK=3840
IS_TEXT_UNICODE_NULL_BYTES=4096
IS_TEXT_UNICODE_ODD_LENGTH=512
IS_TEXT_UNICODE_REVERSE_ASCII16=16
IS_TEXT_UNICODE_REVERSE_CONTROLS=64
IS_TEXT_UNICODE_REVERSE_MASK=240
IS_TEXT_UNICODE_REVERSE_SIGNATURE=128
IS_TEXT_UNICODE_REVERSE_STATISTICS=32
IS_TEXT_UNICODE_SIGNATURE=8
IS_TEXT_UNICODE_STATISTICS=2
IS_TEXT_UNICODE_UNICODE_MASK=15
ITALIC_FONTTYPE=512
JOHAB_CHARSET=130
KEYEVENTF_EXTENDEDKEY=1
KEYEVENTF_KEYUP=2
KEY_ALL_ACCESS=983103
KEY_CREATE_LINK=32
KEY_CREATE_SUB_KEY=4
KEY_ENUMERATE_SUB_KEYS=8
KEY_EXECUTE=131097
KEY_NOTIFY=16
KEY_QUERY_VALUE=1
KEY_READ=131097
KEY_SET_VALUE=2
KEY_WOW64_32KEY=512
KEY_WOW64_64KEY=256
KEY_WOW64_RES=768
KEY_WRITE=131078
KF_ALTDOWN=8192
KF_DLGMODE=2048
KF_EXTENDED=256
KF_MENUMODE=4096
KF_REPEAT=16384
KF_UP=32768
KLF_ACTIVATE=1
KLF_NOTELLSHELL=128
KLF_REORDER=8
KLF_REPLACELANG=16
KLF_SETFORPROCESS=256
KLF_SUBSTITUTE_OK=2
KLF_UNLOADPREVIOUS=4
KL_NAMELENGTH=9
LANG_BULGARIAN=2
LANG_CHINESE=4
LANG_CROATIAN=26
LANG_CZECH=5
LANG_DANISH=6
LANG_DUTCH=19
LANG_ENGLISH=9
LANG_FINNISH=11
LANG_FRENCH=12
LANG_GERMAN=7
LANG_GREEK=8
LANG_HUNGARIAN=14
LANG_ICELANDIC=15
LANG_ITALIAN=16
LANG_JAPANESE=17
LANG_KOREAN=18
LANG_NEUTRAL=0
LANG_NORWEGIAN=20
LANG_POLISH=21
LANG_PORTUGUESE=22
LANG_ROMANIAN=24
LANG_RUSSIAN=25
LANG_SLOVAK=27
LANG_SLOVENIAN=36
LANG_SPANISH=10
LANG_SWEDISH=29
LANG_TURKISH=31
LAYOUT_BITMAPORIENTATIONPRESERVED=8
LAYOUT_BTT=2
LAYOUT_ORIENTATIONMASK=7
LAYOUT_RTL=1
LAYOUT_VBH=4
LBN_DBLCLK=2
LBN_ERRSPACE=-2
LBN_KILLFOCUS=5
LBN_SELCANCEL=3
LBN_SELCHANGE=1
LBN_SETFOCUS=4
LBS_DISABLENOSCROLL=4096
LBS_EXTENDEDSEL=2048
LBS_HASSTRINGS=64
LBS_MULTICOLUMN=512
LBS_MULTIPLESEL=8
LBS_NODATA=8192
LBS_NOINTEGRALHEIGHT=256
LBS_NOREDRAW=4
LBS_NOSEL=16384
LBS_NOTIFY=1
LBS_OWNERDRAWFIXED=16
LBS_OWNERDRAWVARIABLE=32
LBS_SORT=2
LBS_STANDARD=10485763
LBS_USETABSTOPS=128
LBS_WANTKEYBOARDINPUT=1024
LB_ADDFILE=406
LB_ADDSTRING=384
LB_CTLCODE=0
LB_DELETESTRING=386
LB_DIR=397
LB_ERR=-1
LB_ERRSPACE=-2
LB_FINDSTRING=399
LB_FINDSTRINGEXACT=418
LB_GETANCHORINDEX=413
LB_GETCARETINDEX=415
LB_GETCOUNT=395
LB_GETCURSEL=392
LB_GETHORIZONTALEXTENT=403
LB_GETITEMDATA=409
LB_GETITEMHEIGHT=417
LB_GETITEMRECT=408
LB_GETLOCALE=422
LB_GETSEL=391
LB_GETSELCOUNT=400
LB_GETSELITEMS=401
LB_GETTEXT=393
LB_GETTEXTLEN=394
LB_GETTOPINDEX=398
LB_INITSTORAGE=424
LB_INSERTSTRING=385
LB_ITEMFROMPOINT=425
LB_MSGMAX=432
LB_OKAY=0
LB_RESETCONTENT=388
LB_SELECTSTRING=396
LB_SELITEMRANGE=411
LB_SELITEMRANGEEX=387
LB_SETANCHORINDEX=412
LB_SETCARETINDEX=414
LB_SETCOLUMNWIDTH=405
LB_SETCOUNT=423
LB_SETCURSEL=390
LB_SETHORIZONTALEXTENT=404
LB_SETITEMDATA=410
LB_SETITEMHEIGHT=416
LB_SETLOCALE=421
LB_SETSEL=389
LB_SETTABSTOPS=402
LB_SETTOPINDEX=407
LC_INTERIORS=128
LC_MARKER=4
LC_NONE=0
LC_POLYLINE=2
LC_POLYMARKER=8
LC_STYLED=32
LC_WIDE=16
LC_WIDESTYLED=64
LEFT_ALT_PRESSED=2
LEFT_CTRL_PRESSED=8
LF_FACESIZE=32
LF_FULLFACESIZE=64
LHND=66
LINECAPS=30
LLKHF_ALTDOWN=32
LLKHF_EXTENDED=1
LLKHF_INJECTED=16
LLKHF_UP=128
LLMHF_INJECTED=1
LMEM_DISCARDABLE=3840
LMEM_DISCARDED=16384
LMEM_FIXED=0
LMEM_INVALID_HANDLE=32768
LMEM_LOCKCOUNT=255
LMEM_MODIFY=128
LMEM_MOVEABLE=2
LMEM_NOCOMPACT=16
LMEM_NODISCARD=32
LMEM_VALID_FLAGS=3954
LMEM_ZEROINIT=64
LOAD_DLL_DEBUG_EVENT=6
LOAD_LIBRARY_AS_DATAFILE=2
LOAD_WITH_ALTERED_SEARCH_PATH=8
LOCKFILE_EXCLUSIVE_LOCK=2
LOCKFILE_FAIL_IMMEDIATELY=1
LOCKF_LOGICAL_LOCK=0
LOCKF_PHYSICAL_LOCK=1
LOCKP_ALLOW_MEM_MAPPING=0
LOCKP_ALLOW_WRITES=1
LOCKP_FAIL_MEM_MAPPING=2
LOCKP_FAIL_WRITES=0
LOCKP_LOCK_FOR_FORMAT=4
LOCKP_USER_MASK=3
LOGON32_LOGON_BATCH=4
LOGON32_LOGON_INTERACTIVE=2
LOGON32_LOGON_NETWORK=3
LOGON32_LOGON_NETWORK_CLEARTEXT=8
LOGON32_LOGON_NEW_CREDENTIALS=9
LOGON32_LOGON_SERVICE=5
LOGON32_LOGON_UNLOCK=7
LOGON32_PROVIDER_DEFAULT=0
LOGON32_PROVIDER_WINNT35=1
LOGON32_PROVIDER_WINNT40=2
LOGON32_PROVIDER_WINNT50=3
LOGPIXELSX=88
LOGPIXELSY=90
LPTR=64
LR_COLOR=2
LR_COPYDELETEORG=8
LR_COPYFROMRESOURCE=16384
LR_COPYRETURNORG=4
LR_CREATEDIBSECTION=8192
LR_DEFAULTCOLOR=0
LR_DEFAULTSIZE=64
LR_LOADFROMFILE=16
LR_LOADMAP3DCOLORS=4096
LR_LOADREALSIZE=128
LR_LOADTRANSPARENT=32
LR_MONOCHROME=1
LR_SHARED=32768
LTGRAY_BRUSH=1
LWA_ALPHA=2
LWA_COLORKEY=1
MAC_CHARSET=77
MARKPARITY=3
MAXBYTE=255
MAXCHAR=127
MAXDWORD=-1
MAXIMUM_ALLOWED=33554432
MAXINTATOM=49152
MAXLONG=2147483647
MAXSHORT=32767
MAXSTRETCHBLTMODE=4
MAXWORD=65535
MAX_COMPUTERNAME_LENGTH=15
MAX_PATH=260
MAX_TAB_STOPS=32
MA_ACTIVATE=1
MA_ACTIVATEANDEAT=2
MA_NOACTIVATE=3
MA_NOACTIVATEANDEAT=4
MB_ABORTRETRYIGNORE=2
MB_APPLMODAL=0
MB_DEFAULT_DESKTOP_ONLY=131072
MB_DEFBUTTON1=0
MB_DEFBUTTON2=256
MB_DEFBUTTON3=512
MB_DEFBUTTON4=768
MB_DEFMASK=3840
MB_HELP=16384
MB_ICONASTERISK=64
MB_ICONERROR=16
MB_ICONEXCLAMATION=48
MB_ICONHAND=16
MB_ICONINFORMATION=64
MB_ICONMASK=240
MB_ICONQUESTION=32
MB_ICONSTOP=16
MB_ICONWARNING=48
MB_MISCMASK=49152
MB_MODEMASK=12288
MB_NOFOCUS=32768
MB_OK=0
MB_OKCANCEL=1
MB_RETRYCANCEL=5
MB_RIGHT=524288
MB_RTLREADING=1048576
MB_SERVICE_NOTIFICATION=2097152
MB_SETFOREGROUND=65536
MB_SYSTEMMODAL=4096
MB_TASKMODAL=8192
MB_TOPMOST=262144
MB_TYPEMASK=15
MB_USERICON=128
MB_YESNO=4
MB_YESNOCANCEL=3
MDIS_ALLCHILDSTYLES=1
MDITILE_HORIZONTAL=1
MDITILE_SKIPDISABLED=2
MDITILE_VERTICAL=0
MEM_COMMIT=4096
MEM_DECOMMIT=16384
MEM_FREE=65536
MEM_IMAGE=16777216
MEM_MAPPED=262144
MEM_PRIVATE=131072
MEM_RELEASE=32768
MEM_RESERVE=8192
MEM_TOP_DOWN=1048576
MENULOOP_POPUP=1
MENULOOP_WINDOW=0
MERGECOPY=12583114
MERGEPAINT=12255782
MESSAGE_RESOURCE_UNICODE=1
META_ANIMATEPALETTE=1078
META_ARC=2071
META_BITBLT=2338
META_CHORD=2096
META_CREATEBRUSHINDIRECT=764
META_CREATEFONTINDIRECT=763
META_CREATEPALETTE=247
META_CREATEPATTERNBRUSH=505
META_CREATEPENINDIRECT=762
META_CREATEREGION=1791
META_DELETEOBJECT=496
META_DIBBITBLT=2368
META_DIBCREATEPATTERNBRUSH=322
META_DIBSTRETCHBLT=2881
META_ELLIPSE=1048
META_ESCAPE=1574
META_EXCLUDECLIPRECT=1045
META_EXTFLOODFILL=1352
META_EXTTEXTOUT=2610
META_FILLREGION=552
META_FLOODFILL=1049
META_FRAMEREGION=1065
META_INTERSECTCLIPRECT=1046
META_INVERTREGION=298
META_LINETO=531
META_MOVETO=532
META_OFFSETCLIPRGN=544
META_OFFSETVIEWPORTORG=529
META_OFFSETWINDOWORG=527
META_PAINTREGION=299
META_PATBLT=1565
META_PIE=2074
META_POLYGON=804
META_POLYLINE=805
META_POLYPOLYGON=1336
META_REALIZEPALETTE=53
META_RECTANGLE=1051
META_RESIZEPALETTE=313
META_RESTOREDC=295
META_ROUNDRECT=1564
META_SAVEDC=30
META_SCALEVIEWPORTEXT=1042
META_SCALEWINDOWEXT=1040
META_SELECTCLIPREGION=300
META_SELECTOBJECT=301
META_SELECTPALETTE=564
META_SETBKCOLOR=513
META_SETBKMODE=258
META_SETDIBTODEV=3379
META_SETMAPMODE=259
META_SETMAPPERFLAGS=561
META_SETPALENTRIES=55
META_SETPIXEL=1055
META_SETPOLYFILLMODE=262
META_SETRELABS=261
META_SETROP2=260
META_SETSTRETCHBLTMODE=263
META_SETTEXTALIGN=302
META_SETTEXTCHAREXTRA=264
META_SETTEXTCOLOR=521
META_SETTEXTJUSTIFICATION=522
META_SETVIEWPORTEXT=526
META_SETVIEWPORTORG=525
META_SETWINDOWEXT=524
META_SETWINDOWORG=523
META_STRETCHBLT=2851
META_STRETCHDIB=3907
META_TEXTOUT=1313
METRICS_USEDEFAULT=-1
MFCOMMENT=15
MFS_BOTTOMGAPDROP=1073741824
MFS_CACHEDBMP=536870912
MFS_CHECKED=8
MFS_DEFAULT=4096
MFS_DISABLED=3
MFS_ENABLED=0
MFS_GAPDROP=-1073741824
MFS_GRAYED=3
MFS_HILITE=128
MFS_HOTTRACKDRAWN=268435456
MFS_MASK=4235
MFS_TOPGAPDROP=-2147483648
MFS_UNCHECKED=0
MFS_UNHILITE=0
MFT_BITMAP=4
MFT_MENUBARBREAK=32
MFT_MENUBREAK=64
MFT_OWNERDRAW=256
MFT_RADIOCHECK=512
MFT_RIGHTJUSTIFY=16384
MFT_RIGHTORDER=8192
MFT_SEPARATOR=2048
MFT_STRING=0
MF_APPEND=256
MF_BITMAP=4
MF_BYCOMMAND=0
MF_BYPOSITION=1024
MF_CHANGE=128
MF_CHECKED=8
MF_DEFAULT=4096
MF_DELETE=512
MF_DISABLED=2
MF_ENABLED=0
MF_END=128
MF_GRAYED=1
MF_HELP=16384
MF_HILITE=128
MF_INSERT=0
MF_MENUBARBREAK=32
MF_MENUBREAK=64
MF_MOUSESELECT=32768
MF_OWNERDRAW=256
MF_POPUP=16
MF_REMOVE=4096
MF_RIGHTJUSTIFY=16384
MF_SEPARATOR=2048
MF_STRING=0
MF_SYSMENU=8192
MF_UNCHECKED=0
MF_UNHILITE=0
MF_USECHECKBITMAPS=512
MIIM_BITMAP=128
MIIM_CHECKMARKS=8
MIIM_DATA=32
MIIM_FTYPE=256
MIIM_ID=2
MIIM_STATE=1
MIIM_STRING=64
MIIM_SUBMENU=4
MIIM_TYPE=16
MIM_APPLYTOSUBMENUS=-2147483648
MIM_BACKGROUND=2
MIM_HELPID=4
MIM_MAXHEIGHT=1
MIM_MENUDATA=8
MIM_STYLE=16
MINCHAR=128
MINLONG=-2147483648
MINSHORT=32768
MKF_AVAILABLE=2
MKF_CONFIRMHOTKEY=8
MKF_HOTKEYACTIVE=4
MKF_HOTKEYSOUND=16
MKF_INDICATOR=32
MKF_LEFTBUTTONDOWN=16777216
MKF_LEFTBUTTONSEL=268435456
MKF_MODIFIERS=64
MKF_MOUSEKEYSON=1
MKF_MOUSEMODE=-2147483648
MKF_REPLACENUMBERS=128
MKF_RIGHTBUTTONDOWN=33554432
MKF_RIGHTBUTTONSEL=536870912
MK_CONTROL=8
MK_LBUTTON=1
MK_MBUTTON=16
MK_RBUTTON=2
MK_SHIFT=4
MM_ANISOTROPIC=8
MM_HIENGLISH=5
MM_HIMETRIC=3
MM_ISOTROPIC=7
MM_LOENGLISH=4
MM_LOMETRIC=2
MM_MAX=8
MM_MAX_FIXEDSCALE=6
MM_MIN=1
MM_TEXT=1
MM_TWIPS=6
MM_WORKING_SET_MAX_HARD_DISABLE=2
MM_WORKING_SET_MAX_HARD_ENABLE=1
MM_WORKING_SET_MIN_HARD_DISABLE=8
MM_WORKING_SET_MIN_HARD_ENABLE=4
MNC_CLOSE=1
MNC_EXECUTE=2
MNC_IGNORE=0
MNC_SELECT=3
MND_CONTINUE=0
MND_ENDMENU=1
MNGOF_GAP=3
MNGO_NOERROR=1
MNGO_NOINTERFACE=0
MNS_AUTODISMISS=268435456
MNS_CHECKORBMP=67108864
MNS_DRAGDROP=536870912
MNS_MODELESS=1073741824
MNS_NOCHECK=-2147483648
MNS_NOTIFYBYPOS=134217728
MOD_ALT=1
MOD_CONTROL=2
MOD_SHIFT=4
MOD_WIN=8
MONITORINFOF_PRIMARY=1
MONITOR_DEFAULTTONEAREST=2
MONITOR_DEFAULTTONULL=0
MONITOR_DEFAULTTOPRIMARY=1
MOUSEEVENTF_ABSOLUTE=32768
MOUSEEVENTF_HWHEEL=4096
MOUSEEVENTF_LEFTDOWN=2
MOUSEEVENTF_LEFTUP=4
MOUSEEVENTF_MIDDLEDOWN=32
MOUSEEVENTF_MIDDLEUP=64
MOUSEEVENTF_MOVE=1
MOUSEEVENTF_RIGHTDOWN=8
MOUSEEVENTF_RIGHTUP=16
MOUSEEVENTF_WHEEL=2048
MOUSEEVENTF_XDOWN=128
MOUSEEVENTF_XUP=256
MOUSETRAILS=39
MOUSE_MOVED=1
MOUSE_WHEELED=4
MOVEFILE_COPY_ALLOWED=2
MOVEFILE_DELAY_UNTIL_REBOOT=4
MOVEFILE_REPLACE_EXISTING=1
MSGF_DIALOGBOX=0
MSGF_MAX=8
MSGF_MENU=2
MSGF_MESSAGEBOX=1
MSGF_NEXTWINDOW=6
MSGF_SCROLLBAR=5
MSGF_USER=4096
MUTANT_QUERY_STATE=1
MWMO_ALERTABLE=2
MWMO_INPUTAVAILABLE=4
MWMO_WAITALL=1
MWT_IDENTITY=1
MWT_LEFTMULTIPLY=2
MWT_MAX=3
MWT_MIN=1
MWT_RIGHTMULTIPLY=3
NEWFRAME=1
NEXTBAND=3
NFR_ANSI=1
NFR_UNICODE=2
NF_QUERY=3
NF_REQUERY=4
NLS_ALPHANUMERIC=0
NLS_DBCSCHAR=65536
NLS_HIRAGANA=262144
NLS_IME_CONVERSION=8388608
NLS_IME_DISABLE=536870912
NLS_KATAKANA=131072
NLS_ROMAN=4194304
NLS_VALID_LOCALE_MASK=1048575
NMPWAIT_NOWAIT=1
NMPWAIT_USE_DEFAULT_WAIT=0
NMPWAIT_WAIT_FOREVER=-1
NONANTIALIASED_QUALITY=3
NONZEROLHND=2
NONZEROLPTR=0
NOPARITY=0
NORMAL_PRIORITY_CLASS=32
NOTSRCCOPY=3342344
NOTSRCERASE=1114278
NO_PROPAGATE_INHERIT_ACE=4
NTM_BOLD=32
NTM_ITALIC=1
NTM_REGULAR=64
NULL=0
NULLREGION=1
NULL_BRUSH=5
NULL_PEN=8
NUMBRUSHES=16
NUMCOLORS=24
NUMFONTS=22
NUMLOCK_ON=32
NUMMARKERS=20
NUMPENS=18
NUMRESERVED=106
N_BTMASK=15
N_BTSHFT=4
N_TMASK=48
N_TMASK1=192
N_TMASK2=240
N_TSHIFT=2
NameCanonical=7
NameCanonicalEx=9
NameDisplay=3
NameDnsDomain=12
NameFullyQualifiedDN=1
NameSamCompatible=2
NameServicePrincipal=10
NameUniqueId=6
NameUnknown=0
NameUserPrincipal=8
OBJECT_INHERIT_ACE=1
OBJID_ALERT=-10
OBJID_CARET=-8
OBJID_CLIENT=-4
OBJID_CURSOR=-9
OBJID_HSCROLL=-6
OBJID_MENU=-3
OBJID_SIZEGRIP=-7
OBJID_SOUND=-11
OBJID_SYSMENU=-1
OBJID_TITLEBAR=-2
OBJID_VSCROLL=-5
OBJID_WINDOW=0
OBJ_BITMAP=7
OBJ_BRUSH=2
OBJ_COLORSPACE=14
OBJ_DC=3
OBJ_ENHMETADC=12
OBJ_ENHMETAFILE=13
OBJ_EXTPEN=11
OBJ_FONT=6
OBJ_MEMDC=10
OBJ_METADC=4
OBJ_METAFILE=9
OBJ_PAL=5
OBJ_PEN=1
OBJ_REGION=8
OBM_BTNCORNERS=32758
OBM_BTSIZE=32761
OBM_CHECK=32760
OBM_CHECKBOXES=32759
OBM_CLOSE=32754
OBM_COMBO=32738
OBM_DNARROW=32752
OBM_DNARROWD=32742
OBM_DNARROWI=32736
OBM_LFARROW=32750
OBM_LFARROWD=32740
OBM_LFARROWI=32734
OBM_MNARROW=32739
OBM_OLD_CLOSE=32767
OBM_OLD_DNARROW=32764
OBM_OLD_LFARROW=32762
OBM_OLD_REDUCE=32757
OBM_OLD_RESTORE=32755
OBM_OLD_RGARROW=32763
OBM_OLD_UPARROW=32765
OBM_OLD_ZOOM=32756
OBM_REDUCE=32749
OBM_REDUCED=32746
OBM_RESTORE=32747
OBM_RESTORED=32744
OBM_RGARROW=32751
OBM_RGARROWD=32741
OBM_RGARROWI=32735
OBM_SIZE=32766
OBM_UPARROW=32753
OBM_UPARROWD=32743
OBM_UPARROWI=32737
OBM_ZOOM=32748
OBM_ZOOMD=32745
OCR_APPSTARTING=32650
OCR_CROSS=32515
OCR_HAND=32649
OCR_IBEAM=32513
OCR_ICOCUR=32647
OCR_ICON=32641
OCR_NO=32648
OCR_NORMAL=32512
OCR_SIZE=32640
OCR_SIZEALL=32646
OCR_SIZENESW=32643
OCR_SIZENS=32645
OCR_SIZENWSE=32642
OCR_SIZEWE=32644
OCR_UP=32516
OCR_WAIT=32514
ODA_DRAWENTIRE=1
ODA_FOCUS=4
ODA_SELECT=2
ODDPARITY=1
ODS_CHECKED=8
ODS_COMBOBOXEDIT=4096
ODS_DEFAULT=32
ODS_DISABLED=4
ODS_FOCUS=16
ODS_GRAYED=2
ODS_HOTLIGHT=64
ODS_INACTIVE=128
ODS_SELECTED=1
ODT_BUTTON=4
ODT_COMBOBOX=3
ODT_LISTBOX=2
ODT_MENU=1
ODT_STATIC=5
OEM_CHARSET=255
OEM_FIXED_FONT=10
OFN_ALLOWMULTISELECT=512
OFN_CREATEPROMPT=8192
OFN_DONTADDTORECENT=33554432
OFN_ENABLEHOOK=32
OFN_ENABLEINCLUDENOTIFY=4194304
OFN_ENABLESIZING=8388608
OFN_ENABLETEMPLATE=64
OFN_ENABLETEMPLATEHANDLE=128
OFN_EXPLORER=524288
OFN_EXTENSIONDIFFERENT=1024
OFN_EX_NOPLACESBAR=1
OFN_FILEMUSTEXIST=4096
OFN_FORCESHOWHIDDEN=268435456
OFN_HIDEREADONLY=4
OFN_LONGNAMES=2097152
OFN_NOCHANGEDIR=8
OFN_NODEREFERENCELINKS=1048576
OFN_NOLONGNAMES=262144
OFN_NONETWORKBUTTON=131072
OFN_NOREADONLYRETURN=32768
OFN_NOTESTFILECREATE=65536
OFN_NOVALIDATE=256
OFN_OVERWRITEPROMPT=2
OFN_PATHMUSTEXIST=2048
OFN_READONLY=1
OFN_SHAREAWARE=16384
OFN_SHAREFALLTHROUGH=2
OFN_SHARENOWARN=1
OFN_SHAREWARN=0
OFN_SHOWHELP=16
OFS_MAXPATHNAME=128
OF_CANCEL=2048
OF_CREATE=4096
OF_DELETE=512
OF_EXIST=16384
OF_PARSE=256
OF_PROMPT=8192
OF_READ=0
OF_READWRITE=2
OF_REOPEN=32768
OF_SHARE_COMPAT=0
OF_SHARE_DENY_NONE=64
OF_SHARE_DENY_READ=48
OF_SHARE_DENY_WRITE=32
OF_SHARE_EXCLUSIVE=16
OF_VERIFY=1024
OF_WRITE=1
OIC_BANG=32515
OIC_ERROR=32513
OIC_HAND=32513
OIC_INFORMATION=32516
OIC_NOTE=32516
OIC_QUES=32514
OIC_SAMPLE=32512
OIC_WARNING=32515
OIC_WINLOGO=32517
OLEOP_DOVERB=1
ONE5STOPBITS=1
ONESTOPBIT=0
OPAQUE=2
OPENCHANNEL=4110
OPENTYPE_FONTTYPE=65536
OPEN_ALWAYS=4
OPEN_EXISTING=3
ORD_LANGDRIVER=1
OUTPUT_DEBUG_STRING_EVENT=8
OUT_CHARACTER_PRECIS=2
OUT_DEFAULT_PRECIS=0
OUT_DEVICE_PRECIS=5
OUT_OUTLINE_PRECIS=8
OUT_RASTER_PRECIS=6
OUT_STRING_PRECIS=1
OUT_STROKE_PRECIS=3
OUT_TT_ONLY_PRECIS=7
OUT_TT_PRECIS=4
OWNER_SECURITY_INFORMATION=1
PAGE_EXECUTE=16
PAGE_EXECUTE_READ=32
PAGE_EXECUTE_READWRITE=64
PAGE_EXECUTE_WRITECOPY=128
PAGE_GUARD=256
PAGE_NOACCESS=1
PAGE_NOCACHE=512
PAGE_READONLY=2
PAGE_READWRITE=4
PAGE_WRITECOPY=8
PANOSE_COUNT=10
PAN_ANY=0
PAN_ARMSTYLE_INDEX=6
PAN_BENT_ARMS_DOUBLE_SERIF=11
PAN_BENT_ARMS_HORZ=7
PAN_BENT_ARMS_SINGLE_SERIF=10
PAN_BENT_ARMS_VERT=9
PAN_BENT_ARMS_WEDGE=8
PAN_CONTRAST_HIGH=8
PAN_CONTRAST_INDEX=4
PAN_CONTRAST_LOW=4
PAN_CONTRAST_MEDIUM=6
PAN_CONTRAST_MEDIUM_HIGH=7
PAN_CONTRAST_MEDIUM_LOW=5
PAN_CONTRAST_NONE=2
PAN_CONTRAST_VERY_HIGH=9
PAN_CONTRAST_VERY_LOW=3
PAN_CULTURE_LATIN=0
PAN_FAMILYTYPE_INDEX=0
PAN_FAMILY_DECORATIVE=4
PAN_FAMILY_PICTORIAL=5
PAN_FAMILY_SCRIPT=3
PAN_FAMILY_TEXT_DISPLAY=2
PAN_LETTERFORM_INDEX=7
PAN_LETT_NORMAL_BOXED=4
PAN_LETT_NORMAL_CONTACT=2
PAN_LETT_NORMAL_FLATTENED=5
PAN_LETT_NORMAL_OFF_CENTER=7
PAN_LETT_NORMAL_ROUNDED=6
PAN_LETT_NORMAL_SQUARE=8
PAN_LETT_NORMAL_WEIGHTED=3
PAN_LETT_OBLIQUE_BOXED=11
PAN_LETT_OBLIQUE_CONTACT=9
PAN_LETT_OBLIQUE_FLATTENED=12
PAN_LETT_OBLIQUE_OFF_CENTER=14
PAN_LETT_OBLIQUE_ROUNDED=13
PAN_LETT_OBLIQUE_SQUARE=15
PAN_LETT_OBLIQUE_WEIGHTED=10
PAN_MIDLINE_CONSTANT_POINTED=9
PAN_MIDLINE_CONSTANT_SERIFED=10
PAN_MIDLINE_CONSTANT_TRIMMED=8
PAN_MIDLINE_HIGH_POINTED=6
PAN_MIDLINE_HIGH_SERIFED=7
PAN_MIDLINE_HIGH_TRIMMED=5
PAN_MIDLINE_INDEX=8
PAN_MIDLINE_LOW_POINTED=12
PAN_MIDLINE_LOW_SERIFED=13
PAN_MIDLINE_LOW_TRIMMED=11
PAN_MIDLINE_STANDARD_POINTED=3
PAN_MIDLINE_STANDARD_SERIFED=4
PAN_MIDLINE_STANDARD_TRIMMED=2
PAN_NO_FIT=1
PAN_PROPORTION_INDEX=3
PAN_PROP_CONDENSED=6
PAN_PROP_EVEN_WIDTH=4
PAN_PROP_EXPANDED=5
PAN_PROP_MODERN=3
PAN_PROP_MONOSPACED=9
PAN_PROP_OLD_STYLE=2
PAN_PROP_VERY_CONDENSED=8
PAN_PROP_VERY_EXPANDED=7
PAN_SERIFSTYLE_INDEX=1
PAN_SERIF_BONE=8
PAN_SERIF_COVE=2
PAN_SERIF_EXAGGERATED=9
PAN_SERIF_FLARED=14
PAN_SERIF_NORMAL_SANS=11
PAN_SERIF_OBTUSE_COVE=3
PAN_SERIF_OBTUSE_SANS=12
PAN_SERIF_OBTUSE_SQUARE_COVE=5
PAN_SERIF_PERP_SANS=13
PAN_SERIF_ROUNDED=15
PAN_SERIF_SQUARE=6
PAN_SERIF_SQUARE_COVE=4
PAN_SERIF_THIN=7
PAN_SERIF_TRIANGLE=10
PAN_STRAIGHT_ARMS_DOUBLE_SERIF=6
PAN_STRAIGHT_ARMS_HORZ=2
PAN_STRAIGHT_ARMS_SINGLE_SERIF=5
PAN_STRAIGHT_ARMS_VERT=4
PAN_STRAIGHT_ARMS_WEDGE=3
PAN_STROKEVARIATION_INDEX=5
PAN_STROKE_GRADUAL_DIAG=2
PAN_STROKE_GRADUAL_HORZ=5
PAN_STROKE_GRADUAL_TRAN=3
PAN_STROKE_GRADUAL_VERT=4
PAN_STROKE_INSTANT_VERT=8
PAN_STROKE_RAPID_HORZ=7
PAN_STROKE_RAPID_VERT=6
PAN_WEIGHT_BLACK=10
PAN_WEIGHT_BOLD=8
PAN_WEIGHT_BOOK=5
PAN_WEIGHT_DEMI=7
PAN_WEIGHT_HEAVY=9
PAN_WEIGHT_INDEX=2
PAN_WEIGHT_LIGHT=3
PAN_WEIGHT_MEDIUM=6
PAN_WEIGHT_NORD=11
PAN_WEIGHT_THIN=4
PAN_WEIGHT_VERY_LIGHT=2
PAN_XHEIGHT_CONSTANT_LARGE=4
PAN_XHEIGHT_CONSTANT_SMALL=2
PAN_XHEIGHT_CONSTANT_STD=3
PAN_XHEIGHT_DUCKING_LARGE=7
PAN_XHEIGHT_DUCKING_SMALL=5
PAN_XHEIGHT_DUCKING_STD=6
PAN_XHEIGHT_INDEX=9
PASSTHROUGH=19
PATCOPY=15728673
PATINVERT=5898313
PATPAINT=16452105
PBTF_APMRESUMEFROMFAILURE=1
PBT_APMBATTERYLOW=9
PBT_APMOEMEVENT=11
PBT_APMPOWERSTATUSCHANGE=10
PBT_APMQUERYSTANDBY=1
PBT_APMQUERYSTANDBYFAILED=3
PBT_APMQUERYSUSPEND=0
PBT_APMQUERYSUSPENDFAILED=2
PBT_APMRESUMEAUTOMATIC=18
PBT_APMRESUMECRITICAL=6
PBT_APMRESUMESTANDBY=8
PBT_APMRESUMESUSPEND=7
PBT_APMSTANDBY=5
PBT_APMSUSPEND=4
PC_DELIMITER=4
PC_EXPLICIT=2
PC_FOLLOWING=1
PC_INTERIORS=128
PC_LEADING=2
PC_NOCOLLAPSE=4
PC_NONE=0
PC_OVERFLOW=3
PC_POLYGON=1
PC_RECTANGLE=2
PC_RESERVED=1
PC_SCANLINE=8
PC_STYLED=32
PC_TRAPEZOID=4
PC_WIDE=16
PC_WIDESTYLED=64
PC_WINDPOLYGON=4
PDEVICESIZE=26
PD_ALLPAGES=0
PD_COLLATE=16
PD_DISABLEPRINTTOFILE=524288
PD_ENABLEPRINTHOOK=4096
PD_ENABLEPRINTTEMPLATE=16384
PD_ENABLEPRINTTEMPLATEHANDLE=65536
PD_ENABLESETUPHOOK=8192
PD_ENABLESETUPTEMPLATE=32768
PD_ENABLESETUPTEMPLATEHANDLE=131072
PD_HIDEPRINTTOFILE=1048576
PD_NONETWORKBUTTON=2097152
PD_NOPAGENUMS=8
PD_NOSELECTION=4
PD_NOWARNING=128
PD_PAGENUMS=2
PD_PRINTSETUP=64
PD_PRINTTOFILE=32
PD_RETURNDC=256
PD_RETURNDEFAULT=1024
PD_RETURNIC=512
PD_SELECTION=1
PD_SHOWHELP=2048
PD_USEDEVMODECOPIES=262144
PFA_CENTER=3
PFA_LEFT=1
PFA_RIGHT=2
PFM_ALIGNMENT=8
PFM_NUMBERING=32
PFM_OFFSET=4
PFM_OFFSETINDENT=-2147483648
PFM_RIGHTINDENT=2
PFM_STARTINDENT=1
PFM_TABSTOPS=16
PFN_BULLET=1
PHYSICALHEIGHT=111
PHYSICALOFFSETX=112
PHYSICALOFFSETY=113
PHYSICALWIDTH=110
PIPE_ACCESS_DUPLEX=3
PIPE_ACCESS_INBOUND=1
PIPE_ACCESS_OUTBOUND=2
PIPE_CLIENT_END=0
PIPE_NOWAIT=1
PIPE_READMODE_BYTE=0
PIPE_READMODE_MESSAGE=2
PIPE_SERVER_END=1
PIPE_TYPE_BYTE=0
PIPE_TYPE_MESSAGE=4
PIPE_UNLIMITED_INSTANCES=255
PIPE_WAIT=0
PLANES=14
PM_NOREMOVE=0
PM_NOYIELD=2
PM_REMOVE=1
POLYFILL_LAST=2
POLYGONALCAPS=32
POSTSCRIPT_DATA=37
POSTSCRIPT_IGNORE=38
POSTSCRIPT_PASSTHROUGH=4115
PRF_CHECKVISIBLE=1
PRF_CHILDREN=16
PRF_CLIENT=4
PRF_ERASEBKGND=8
PRF_NONCLIENT=2
PRF_OWNED=32
PRINTER_FONTTYPE=16384
PRINTRATEUNIT_CPS=2
PRINTRATEUNIT_IPM=4
PRINTRATEUNIT_LPM=3
PRINTRATEUNIT_PPM=1
PRIVILEGE_SET_ALL_NECESSARY=1
PROCESSOR_ALPHA_21064=21064
PROCESSOR_INTEL_386=386
PROCESSOR_INTEL_486=486
PROCESSOR_INTEL_860=860
PROCESSOR_INTEL_PENTIUM=586
PROCESSOR_MIPS_R2000=2000
PROCESSOR_MIPS_R3000=3000
PROCESSOR_MIPS_R4000=4000
PROCESSOR_PPC_601=601
PROCESSOR_PPC_603=603
PROCESSOR_PPC_604=604
PROCESSOR_PPC_620=620
PROCESS_ALL_ACCESS=2035711
PROCESS_CREATE_PROCESS=128
PROCESS_CREATE_THREAD=2
PROCESS_DUP_HANDLE=64
PROCESS_HEAP_ENTRY_BUSY=4
PROCESS_HEAP_ENTRY_DDESHARE=32
PROCESS_HEAP_ENTRY_MOVEABLE=16
PROCESS_HEAP_REGION=1
PROCESS_HEAP_UNCOMMITTED_RANGE=2
PROCESS_QUERY_INFORMATION=1024
PROCESS_SET_INFORMATION=512
PROCESS_SET_QUOTA=256
PROCESS_TERMINATE=1
PROCESS_VM_OPERATION=8
PROCESS_VM_READ=16
PROCESS_VM_WRITE=32
PROFILE_KERNEL=536870912
PROFILE_SERVER=1073741824
PROFILE_USER=268435456
PROOF_QUALITY=2
PR_JOBSTATUS=0
PSD_DEFAULTMINMARGINS=0
PSD_DISABLEMARGINS=16
PSD_DISABLEORIENTATION=256
PSD_DISABLEPAGEPAINTING=524288
PSD_DISABLEPAPER=512
PSD_DISABLEPRINTER=32
PSD_ENABLEPAGEPAINTHOOK=262144
PSD_ENABLEPAGESETUPHOOK=8192
PSD_ENABLEPAGESETUPTEMPLATE=32768
PSD_ENABLEPAGESETUPTEMPLATEHANDLE=131072
PSD_INHUNDREDTHSOFMILLIMETERS=8
PSD_INTHOUSANDTHSOFINCHES=4
PSD_INWININIINTLMEASURE=0
PSD_MARGINS=2
PSD_MINMARGINS=1
PSD_NONETWORKBUTTON=2097152
PSD_NOWARNING=128
PSD_RETURNDEFAULT=1024
PSD_SHOWHELP=2048
PSM_ADDPAGE=1127
PSM_APPLY=1134
PSM_CANCELTOCLOSE=1131
PSM_CHANGED=1128
PSM_GETCURRENTPAGEHWND=1142
PSM_GETRESULT=1159
PSM_GETTABCONTROL=1140
PSM_HWNDTOINDEX=1153
PSM_IDTOINDEX=1157
PSM_INDEXTOHWND=1154
PSM_INDEXTOID=1158
PSM_INDEXTOPAGE=1156
PSM_INSERTPAGE=1143
PSM_ISDIALOGMESSAGE=1141
PSM_PAGETOINDEX=1155
PSM_PRESSBUTTON=1137
PSM_QUERYSIBLINGS=1132
PSM_REBOOTSYSTEM=1130
PSM_RECALCPAGESIZES=1160
PSM_REMOVEPAGE=1126
PSM_RESTARTWINDOWS=1129
PSM_SETCURSEL=1125
PSM_SETCURSELID=1138
PSM_SETFINISHTEXTA=1139
PSM_SETFINISHTEXTW=1145
PSM_SETHEADERSUBTITLEA=1151
PSM_SETHEADERSUBTITLEW=1152
PSM_SETHEADERTITLEA=1149
PSM_SETHEADERTITLEW=1150
PSM_SETTITLEA=1135
PSM_SETTITLEW=1144
PSM_SETWIZBUTTONS=1136
PSM_UNCHANGED=1133
PS_ALTERNATE=8
PS_COSMETIC=0
PS_DASH=1
PS_DASHDOT=3
PS_DASHDOTDOT=4
PS_DOT=2
PS_ENDCAP_FLAT=512
PS_ENDCAP_MASK=3840
PS_ENDCAP_ROUND=0
PS_ENDCAP_SQUARE=256
PS_GEOMETRIC=65536
PS_INSIDEFRAME=6
PS_JOIN_BEVEL=4096
PS_JOIN_MASK=61440
PS_JOIN_MITER=8192
PS_JOIN_ROUND=0
PS_NULL=5
PS_SOLID=0
PS_STYLE_MASK=15
PS_TYPE_MASK=983040
PS_USERSTYLE=7
PT_BEZIERTO=4
PT_CLOSEFIGURE=1
PT_LINETO=2
PT_MOVETO=6
PWR_CRITICALRESUME=3
PWR_FAIL=-1
PWR_OK=1
PWR_SUSPENDREQUEST=1
PWR_SUSPENDRESUME=2
PY_0U=0
QS_ALLEVENTS=191
QS_ALLINPUT=255
QS_HOTKEY=128
QS_INPUT=7
QS_KEY=1
QS_MOUSE=6
QS_MOUSEBUTTON=4
QS_MOUSEMOVE=2
QS_PAINT=32
QS_POSTMESSAGE=8
QS_SENDMESSAGE=64
QS_TIMER=16
QUERYESCSUPPORT=8
R2_BLACK=1
R2_COPYPEN=13
R2_LAST=16
R2_MASKNOTPEN=3
R2_MASKPEN=9
R2_MASKPENNOT=5
R2_MERGENOTPEN=12
R2_MERGEPEN=15
R2_MERGEPENNOT=14
R2_NOP=11
R2_NOT=6
R2_NOTCOPYPEN=4
R2_NOTMASKPEN=8
R2_NOTMERGEPEN=2
R2_NOTXORPEN=10
R2_WHITE=16
R2_XORPEN=7
RASTERCAPS=38
RASTER_FONTTYPE=1
RC_BANDING=2
RC_BIGFONT=1024
RC_BITBLT=1
RC_BITMAP64=8
RC_DEVBITS=32768
RC_DIBTODEV=512
RC_DI_BITMAP=128
RC_FLOODFILL=4096
RC_GDI20_OUTPUT=16
RC_GDI20_STATE=32
RC_OP_DX_OUTPUT=16384
RC_PALETTE=256
RC_SAVEBITMAP=64
RC_SCALING=4
RC_STRETCHBLT=2048
RC_STRETCHDIB=8192
RDH_RECTANGLES=1
RDW_ALLCHILDREN=128
RDW_ERASE=4
RDW_ERASENOW=512
RDW_FRAME=1024
RDW_INTERNALPAINT=2
RDW_INVALIDATE=1
RDW_NOCHILDREN=64
RDW_NOERASE=32
RDW_NOFRAME=2048
RDW_NOINTERNALPAINT=16
RDW_UPDATENOW=256
RDW_VALIDATE=8
READ_CONTROL=131072
REALTIME_PRIORITY_CLASS=256
REGULAR_FONTTYPE=1024
REG_BINARY=3
REG_DWORD=4
REG_DWORD_BIG_ENDIAN=5
REG_DWORD_LITTLE_ENDIAN=4
REG_EXPAND_SZ=2
REG_FULL_RESOURCE_DESCRIPTOR=9
REG_LINK=6
REG_MULTI_SZ=7
REG_NONE=0
REG_NOTIFY_CHANGE_ATTRIBUTES=2
REG_NOTIFY_CHANGE_SECURITY=8
REG_QWORD=11
REG_QWORD_LITTLE_ENDIAN=11
REG_RESOURCE_LIST=8
REG_RESOURCE_REQUIREMENTS_LIST=10
REG_SZ=1
RELATIVE=2
RESTORE_CTM=4100
RES_CURSOR=2
RES_ICON=1
RGN_AND=1
RGN_COPY=5
RGN_DIFF=4
RGN_ERROR=0
RGN_MAX=5
RGN_MIN=1
RGN_OR=2
RGN_XOR=3
RIGHTMOST_BUTTON_PRESSED=2
RIGHT_ALT_PRESSED=1
RIGHT_CTRL_PRESSED=4
RIP_EVENT=9
RTL_CRITSECT_TYPE=0
RTL_RESOURCE_TYPE=1
RTS_CONTROL_DISABLE=0
RTS_CONTROL_ENABLE=1
RTS_CONTROL_HANDSHAKE=2
RTS_CONTROL_TOGGLE=3
RT_ACCELERATOR=9
RT_ANICURSOR=21
RT_ANIICON=22
RT_BITMAP=2
RT_CURSOR=1
RT_DIALOG=5
RT_DLGINCLUDE=17
RT_FONT=8
RT_FONTDIR=7
RT_GROUP_CURSOR=12
RT_GROUP_ICON=14
RT_HTML=23
RT_ICON=3
RT_MENU=4
RT_MESSAGETABLE=11
RT_PLUGPLAY=19
RT_RCDATA=10
RT_STRING=6
RT_VERSION=16
RT_VXD=20
RUSSIAN_CHARSET=204
SACL_SECURITY_INFORMATION=8
SAVE_CTM=4101
SBM_ENABLE_ARROWS=228
SBM_GETPOS=225
SBM_GETRANGE=227
SBM_GETSCROLLINFO=234
SBM_SETPOS=224
SBM_SETRANGE=226
SBM_SETRANGEREDRAW=230
SBM_SETSCROLLINFO=233
SBS_BOTTOMALIGN=4
SBS_HORZ=0
SBS_LEFTALIGN=2
SBS_RIGHTALIGN=4
SBS_SIZEBOX=8
SBS_SIZEBOXBOTTOMRIGHTALIGN=4
SBS_SIZEBOXTOPLEFTALIGN=2
SBS_SIZEGRIP=16
SBS_TOPALIGN=2
SBS_VERT=1
SB_BOTH=3
SB_BOTTOM=7
SB_CTL=2
SB_ENDSCROLL=8
SB_HORZ=0
SB_LEFT=6
SB_LINEDOWN=1
SB_LINELEFT=0
SB_LINERIGHT=1
SB_LINEUP=0
SB_PAGEDOWN=3
SB_PAGELEFT=2
SB_PAGERIGHT=3
SB_PAGEUP=2
SB_RIGHT=7
SB_THUMBPOSITION=4
SB_THUMBTRACK=5
SB_TOP=6
SB_VERT=1
SCALINGFACTORX=114
SCALINGFACTORY=115
SCF_SELECTION=1
SCF_WORD=2
SCREEN_FONTTYPE=8192
SCROLLLOCK_ON=64
SCS_32BIT_BINARY=0
SCS_DOS_BINARY=1
SCS_OS216_BINARY=5
SCS_PIF_BINARY=3
SCS_POSIX_BINARY=4
SCS_WOW_BINARY=2
SC_ARRANGE=61712
SC_CLOSE=61536
SC_CONTEXTHELP=61824
SC_DEFAULT=61792
SC_HOTKEY=61776
SC_HSCROLL=61568
SC_ICON=61472
SC_KEYMENU=61696
SC_MAXIMIZE=61488
SC_MINIMIZE=61472
SC_MONITORPOWER=61808
SC_MOUSEMENU=61584
SC_MOVE=61456
SC_NEXTWINDOW=61504
SC_PREVWINDOW=61520
SC_RESTORE=61728
SC_SCREENSAVE=61760
SC_SEPARATOR=61455
SC_SIZE=61440
SC_TASKLIST=61744
SC_VSCROLL=61552
SC_ZOOM=61488
SECTION_EXTEND_SIZE=16
SECTION_MAP_EXECUTE=8
SECTION_MAP_READ=4
SECTION_MAP_WRITE=2
SECTION_QUERY=1
SECURITY_ANONYMOUS_LOGON_RID=7
SECURITY_BATCH_RID=3
SECURITY_BUILTIN_DOMAIN_RID=32
SECURITY_CONTEXT_TRACKING=262144
SECURITY_CREATOR_GROUP_RID=1
SECURITY_CREATOR_OWNER_RID=0
SECURITY_DESCRIPTOR_MIN_LENGTH=20
SECURITY_DESCRIPTOR_REVISION=1
SECURITY_DESCRIPTOR_REVISION1=1
SECURITY_DIALUP_RID=1
SECURITY_EFFECTIVE_ONLY=524288
SECURITY_INTERACTIVE_RID=4
SECURITY_LOCAL_RID=0
SECURITY_LOCAL_SYSTEM_RID=18
SECURITY_LOGON_IDS_RID=5
SECURITY_LOGON_IDS_RID_COUNT=3
SECURITY_NETWORK_RID=2
SECURITY_NT_NON_UNIQUE=21
SECURITY_NULL_RID=0
SECURITY_SERVICE_RID=6
SECURITY_SQOS_PRESENT=1048576
SECURITY_VALID_SQOS_FLAGS=2031616
SECURITY_WORLD_RID=0
SEC_COMMIT=134217728
SEC_FILE=8388608
SEC_IMAGE=16777216
SEC_NOCACHE=268435456
SEC_RESERVE=67108864
SELECTPAPERSOURCE=18
SEL_EMPTY=0
SEL_MULTICHAR=4
SEL_MULTIOBJECT=8
SEL_OBJECT=2
SEL_TEXT=1
SEMAPHORE_MODIFY_STATE=2
SEM_FAILCRITICALERRORS=1
SEM_NOALIGNMENTFAULTEXCEPT=4
SEM_NOGPFAULTERRORBOX=2
SEM_NOOPENFILEERRORBOX=32768
SERKF_AVAILABLE=2
SERKF_INDICATOR=4
SERKF_SERIALKEYSON=1
SERVICE_ADAPTER=4
SERVICE_AUTO_START=2
SERVICE_BOOT_START=0
SERVICE_DEMAND_START=3
SERVICE_DISABLED=4
SERVICE_DRIVER=11
SERVICE_ERROR_CRITICAL=3
SERVICE_ERROR_IGNORE=0
SERVICE_ERROR_NORMAL=1
SERVICE_ERROR_SEVERE=2
SERVICE_FILE_SYSTEM_DRIVER=2
SERVICE_INTERACTIVE_PROCESS=256
SERVICE_KERNEL_DRIVER=1
SERVICE_RECOGNIZER_DRIVER=8
SERVICE_SYSTEM_START=1
SERVICE_TYPE_ALL=319
SERVICE_WIN32=48
SERVICE_WIN32_OWN_PROCESS=16
SERVICE_WIN32_SHARE_PROCESS=32
SETABORTPROC=9
SETALLJUSTVALUES=771
SETCHARSET=772
SETCOLORTABLE=4
SETCOPYCOUNT=17
SETDIBSCALING=32
SETKERNTRACK=770
SETLINECAP=21
SETLINEJOIN=22
SETMITERLIMIT=23
SET_ARC_DIRECTION=4102
SET_BACKGROUND_COLOR=4103
SET_BOUNDS=4109
SET_CLIP_BOX=4108
SET_MIRROR_MODE=4110
SET_POLY_MODE=4104
SET_SCREEN_ANGLE=4105
SET_SPREAD=4106
SET_TAPE_DRIVE_INFORMATION=1
SET_TAPE_MEDIA_INFORMATION=0
SE_ASSIGNPRIMARYTOKEN_NAME="SeAssignPrimaryTokenPrivilege"
SE_AUDIT_NAME="SeAuditPrivilege"
SE_BACKUP_NAME="SeBackupPrivilege"
SE_CHANGE_NOTIFY_NAME="SeChangeNotifyPrivilege"
SE_CREATE_PAGEFILE_NAME="SeCreatePagefilePrivilege"
SE_CREATE_PERMANENT_NAME="SeCreatePermanentPrivilege"
SE_CREATE_TOKEN_NAME="SeCreateTokenPrivilege"
SE_DACL_DEFAULTED=8
SE_DACL_PRESENT=4
SE_DEBUG_NAME="SeDebugPrivilege"
SE_GROUP_DEFAULTED=2
SE_GROUP_ENABLED=4
SE_GROUP_ENABLED_BY_DEFAULT=2
SE_GROUP_LOGON_ID=-1073741824
SE_GROUP_MANDATORY=1
SE_GROUP_OWNER=8
SE_INCREASE_QUOTA_NAME="SeIncreaseQuotaPrivilege"
SE_INC_BASE_PRIORITY_NAME="SeIncreaseBasePriorityPrivilege"
SE_LOAD_DRIVER_NAME="SeLoadDriverPrivilege"
SE_LOCK_MEMORY_NAME="SeLockMemoryPrivilege"
SE_MACHINE_ACCOUNT_NAME="SeMachineAccountPrivilege"
SE_OWNER_DEFAULTED=1
SE_PRIVILEGE_ENABLED=2
SE_PRIVILEGE_ENABLED_BY_DEFAULT=1
SE_PRIVILEGE_USED_FOR_ACCESS=-2147483648
SE_PROF_SINGLE_PROCESS_NAME="SeProfileSingleProcessPrivilege"
SE_REMOTE_SHUTDOWN_NAME="SeRemoteShutdownPrivilege"
SE_RESTORE_NAME="SeRestorePrivilege"
SE_SACL_DEFAULTED=32
SE_SACL_PRESENT=16
SE_SECURITY_NAME="SeSecurityPrivilege"
SE_SELF_RELATIVE=32768
SE_SHUTDOWN_NAME="SeShutdownPrivilege"
SE_SYSTEMTIME_NAME="SeSystemtimePrivilege"
SE_SYSTEM_ENVIRONMENT_NAME="SeSystemEnvironmentPrivilege"
SE_SYSTEM_PROFILE_NAME="SeSystemProfilePrivilege"
SE_TAKE_OWNERSHIP_NAME="SeTakeOwnershipPrivilege"
SE_TCB_NAME="SeTcbPrivilege"
SE_UNSOLICITED_INPUT_NAME="SeUnsolicitedInputPrivilege"
SFF_PLAINRTF=16384
SFF_SELECTION=32768
SF_RTF=2
SF_RTFNOOBJS=3
SF_TEXT=1
SF_TEXTIZED=4
SHADEBLENDCAPS=120
SHIFTJIS_CHARSET=128
SHIFT_PRESSED=16
SHOW_FULLSCREEN=3
SHOW_ICONWINDOW=2
SHOW_OPENNOACTIVATE=4
SHOW_OPENWINDOW=1
SHUTDOWN_NORETRY=1
SID_MAX_SUB_AUTHORITIES=15
SIF_ALL=23
SIF_DISABLENOSCROLL=8
SIF_PAGE=2
SIF_POS=4
SIF_RANGE=1
SIF_TRACKPOS=16
SIMPLEREGION=2
SIMULATED_FONTTYPE=32768
SIZEFULLSCREEN=2
SIZEICONIC=1
SIZENORMAL=0
SIZEOF_RFPO_DATA=16
SIZEPALETTE=104
SIZEZOOMHIDE=4
SIZEZOOMSHOW=3
SIZE_MAXHIDE=4
SIZE_MAXIMIZED=2
SIZE_MAXSHOW=3
SIZE_MINIMIZED=1
SIZE_OF_80387_REGISTERS=80
SIZE_RESTORED=0
SKF_AUDIBLEFEEDBACK=64
SKF_AVAILABLE=2
SKF_CONFIRMHOTKEY=8
SKF_HOTKEYACTIVE=4
SKF_HOTKEYSOUND=16
SKF_INDICATOR=32
SKF_LALTLATCHED=268435456
SKF_LALTLOCKED=1048576
SKF_LCTLLATCHED=67108864
SKF_LCTLLOCKED=262144
SKF_LSHIFTLATCHED=16777216
SKF_LSHIFTLOCKED=65536
SKF_LWINLATCHED=1073741824
SKF_LWINLOCKED=4194304
SKF_RALTLATCHED=536870912
SKF_RALTLOCKED=2097152
SKF_RCTLLATCHED=134217728
SKF_RCTLLOCKED=524288
SKF_RSHIFTLATCHED=33554432
SKF_RSHIFTLOCKED=131072
SKF_RWINLATCHED=-2147483648
SKF_RWINLOCKED=8388608
SKF_STICKYKEYSON=1
SKF_TRISTATE=128
SKF_TWOKEYSOFF=256
SLE_ERROR=1
SLE_MINORERROR=2
SLE_WARNING=3
SMTO_ABORTIFHUNG=2
SMTO_BLOCK=1
SMTO_NORMAL=0
SMTO_NOTIMEOUTIFNOTHUNG=8
SM_ARRANGE=56
SM_CLEANBOOT=67
SM_CMETRICS=83
SM_CMONITORS=80
SM_CMOUSEBUTTONS=43
SM_CXBORDER=5
SM_CXCURSOR=13
SM_CXDLGFRAME=7
SM_CXDOUBLECLK=36
SM_CXDRAG=68
SM_CXEDGE=45
SM_CXFIXEDFRAME=7
SM_CXFRAME=32
SM_CXFULLSCREEN=16
SM_CXHSCROLL=21
SM_CXHTHUMB=10
SM_CXICON=11
SM_CXICONSPACING=38
SM_CXMAXIMIZED=61
SM_CXMAXTRACK=59
SM_CXMENUCHECK=71
SM_CXMENUSIZE=54
SM_CXMIN=28
SM_CXMINIMIZED=57
SM_CXMINSPACING=47
SM_CXMINTRACK=34
SM_CXSCREEN=0
SM_CXSIZE=30
SM_CXSIZEFRAME=32
SM_CXSMICON=49
SM_CXSMSIZE=52
SM_CXVIRTUALSCREEN=78
SM_CXVSCROLL=2
SM_CYBORDER=6
SM_CYCAPTION=4
SM_CYCURSOR=14
SM_CYDLGFRAME=8
SM_CYDOUBLECLK=37
SM_CYDRAG=69
SM_CYEDGE=46
SM_CYFIXEDFRAME=8
SM_CYFRAME=33
SM_CYFULLSCREEN=17
SM_CYHSCROLL=3
SM_CYICON=12
SM_CYICONSPACING=39
SM_CYKANJIWINDOW=18
SM_CYMAXIMIZED=62
SM_CYMAXTRACK=60
SM_CYMENU=15
SM_CYMENUCHECK=72
SM_CYMENUSIZE=55
SM_CYMIN=29
SM_CYMINIMIZED=58
SM_CYMINSPACING=48
SM_CYMINTRACK=35
SM_CYSCREEN=1
SM_CYSIZE=31
SM_CYSIZEFRAME=33
SM_CYSMCAPTION=51
SM_CYSMICON=50
SM_CYSMSIZE=53
SM_CYVIRTUALSCREEN=79
SM_CYVSCROLL=20
SM_CYVTHUMB=9
SM_DBCSENABLED=42
SM_DEBUG=22
SM_MENUDROPALIGNMENT=40
SM_MIDEASTENABLED=74
SM_MOUSEPRESENT=19
SM_MOUSEWHEELPRESENT=75
SM_NETWORK=63
SM_PENWINDOWS=41
SM_RESERVED1=24
SM_RESERVED2=25
SM_RESERVED3=26
SM_RESERVED4=27
SM_SAMEDISPLAYFORMAT=81
SM_SECURE=44
SM_SHOWSOUNDS=70
SM_SLOWMACHINE=73
SM_SWAPBUTTON=23
SM_XVIRTUALSCREEN=76
SM_YVIRTUALSCREEN=77
SORT_CHINESE_BIG5=0
SORT_CHINESE_UNICODE=1
SORT_DEFAULT=0
SORT_JAPANESE_UNICODE=1
SORT_JAPANESE_XJIS=0
SORT_KOREAN_KSC=0
SORT_KOREAN_UNICODE=1
SOUND_SYSTEM_APPEND=14
SOUND_SYSTEM_APPSTART=12
SOUND_SYSTEM_BEEP=3
SOUND_SYSTEM_ERROR=4
SOUND_SYSTEM_FAULT=13
SOUND_SYSTEM_INFORMATION=7
SOUND_SYSTEM_MAXIMIZE=8
SOUND_SYSTEM_MENUCOMMAND=15
SOUND_SYSTEM_MENUPOPUP=16
SOUND_SYSTEM_MINIMIZE=9
SOUND_SYSTEM_QUESTION=5
SOUND_SYSTEM_RESTOREDOWN=11
SOUND_SYSTEM_RESTOREUP=10
SOUND_SYSTEM_SHUTDOWN=2
SOUND_SYSTEM_STARTUP=1
SOUND_SYSTEM_WARNING=6
SPACEPARITY=4
SPECIFIC_RIGHTS_ALL=65535
SPIF_SENDCHANGE=2
SPIF_SENDWININICHANGE=2
SPIF_UPDATEINIFILE=1
SPI_GETACCESSTIMEOUT=60
SPI_GETACTIVEWINDOWTRACKING=4096
SPI_GETACTIVEWNDTRKTIMEOUT=8194
SPI_GETACTIVEWNDTRKZORDER=4108
SPI_GETANIMATION=72
SPI_GETBEEP=1
SPI_GETBLOCKSENDINPUTRESETS=4134
SPI_GETBORDER=5
SPI_GETCARETWIDTH=8198
SPI_GETCOMBOBOXANIMATION=4100
SPI_GETCURSORSHADOW=4122
SPI_GETDEFAULTINPUTLANG=89
SPI_GETDESKWALLPAPER=115
SPI_GETDRAGFULLWINDOWS=38
SPI_GETDROPSHADOW=4132
SPI_GETFASTTASKSWITCH=35
SPI_GETFILTERKEYS=50
SPI_GETFLATMENU=4130
SPI_GETFOCUSBORDERHEIGHT=8208
SPI_GETFOCUSBORDERWIDTH=8206
SPI_GETFONTSMOOTHING=74
SPI_GETFONTSMOOTHINGCONTRAST=8204
SPI_GETFONTSMOOTHINGORIENTATION=8210
SPI_GETFONTSMOOTHINGTYPE=8202
SPI_GETFOREGROUNDFLASHCOUNT=8196
SPI_GETFOREGROUNDLOCKTIMEOUT=8192
SPI_GETGRADIENTCAPTIONS=4104
SPI_GETGRIDGRANULARITY=18
SPI_GETHIGHCONTRAST=66
SPI_GETHOTTRACKING=4110
SPI_GETICONMETRICS=45
SPI_GETICONTITLELOGFONT=31
SPI_GETICONTITLEWRAP=25
SPI_GETKEYBOARDCUES=4106
SPI_GETKEYBOARDDELAY=22
SPI_GETKEYBOARDPREF=68
SPI_GETKEYBOARDSPEED=10
SPI_GETLISTBOXSMOOTHSCROLLING=4102
SPI_GETLOWPOWERACTIVE=83
SPI_GETLOWPOWERTIMEOUT=79
SPI_GETMENUANIMATION=4098
SPI_GETMENUDROPALIGNMENT=27
SPI_GETMENUFADE=4114
SPI_GETMENUSHOWDELAY=106
SPI_GETMENUUNDERLINES=4106
SPI_GETMINIMIZEDMETRICS=43
SPI_GETMOUSE=3
SPI_GETMOUSECLICKLOCK=4126
SPI_GETMOUSECLICKLOCKTIME=8200
SPI_GETMOUSEHOVERHEIGHT=100
SPI_GETMOUSEHOVERTIME=102
SPI_GETMOUSEHOVERWIDTH=98
SPI_GETMOUSEKEYS=54
SPI_GETMOUSESONAR=4124
SPI_GETMOUSESPEED=112
SPI_GETMOUSETRAILS=94
SPI_GETMOUSEVANISH=4128
SPI_GETNONCLIENTMETRICS=41
SPI_GETPOWEROFFACTIVE=84
SPI_GETPOWEROFFTIMEOUT=80
SPI_GETSCREENREADER=70
SPI_GETSCREENSAVEACTIVE=16
SPI_GETSCREENSAVERRUNNING=114
SPI_GETSCREENSAVETIMEOUT=14
SPI_GETSELECTIONFADE=4116
SPI_GETSERIALKEYS=62
SPI_GETSHOWIMEUI=110
SPI_GETSHOWSOUNDS=56
SPI_GETSNAPTODEFBUTTON=95
SPI_GETSOUNDSENTRY=64
SPI_GETSTICKYKEYS=58
SPI_GETTOGGLEKEYS=52
SPI_GETTOOLTIPANIMATION=4118
SPI_GETTOOLTIPFADE=4120
SPI_GETUIEFFECTS=4158
SPI_GETWHEELSCROLLLINES=104
SPI_GETWINDOWSEXTENSION=92
SPI_GETWORKAREA=48
SPI_ICONHORIZONTALSPACING=13
SPI_ICONVERTICALSPACING=24
SPI_LANGDRIVER=12
SPI_SCREENSAVERRUNNING=97
SPI_SETACCESSTIMEOUT=61
SPI_SETACTIVEWINDOWTRACKING=4097
SPI_SETACTIVEWNDTRKTIMEOUT=8195
SPI_SETACTIVEWNDTRKZORDER=4109
SPI_SETANIMATION=73
SPI_SETBEEP=2
SPI_SETBLOCKSENDINPUTRESETS=4135
SPI_SETBORDER=6
SPI_SETCARETWIDTH=8199
SPI_SETCOMBOBOXANIMATION=4101
SPI_SETCURSORS=87
SPI_SETCURSORSHADOW=4123
SPI_SETDEFAULTINPUTLANG=90
SPI_SETDESKPATTERN=21
SPI_SETDESKWALLPAPER=20
SPI_SETDOUBLECLICKTIME=32
SPI_SETDOUBLECLKHEIGHT=30
SPI_SETDOUBLECLKWIDTH=29
SPI_SETDRAGFULLWINDOWS=37
SPI_SETDRAGHEIGHT=77
SPI_SETDRAGWIDTH=76
SPI_SETDROPSHADOW=4133
SPI_SETFASTTASKSWITCH=36
SPI_SETFILTERKEYS=51
SPI_SETFLATMENU=4131
SPI_SETFOCUSBORDERHEIGHT=8209
SPI_SETFOCUSBORDERWIDTH=8207
SPI_SETFONTSMOOTHING=75
SPI_SETFONTSMOOTHINGCONTRAST=8205
SPI_SETFONTSMOOTHINGORIENTATION=8211
SPI_SETFONTSMOOTHINGTYPE=8203
SPI_SETFOREGROUNDFLASHCOUNT=8197
SPI_SETFOREGROUNDLOCKTIMEOUT=8193
SPI_SETGRADIENTCAPTIONS=4105
SPI_SETGRIDGRANULARITY=19
SPI_SETHANDHELD=78
SPI_SETHIGHCONTRAST=67
SPI_SETHOTTRACKING=4111
SPI_SETICONMETRICS=46
SPI_SETICONS=88
SPI_SETICONTITLELOGFONT=34
SPI_SETICONTITLEWRAP=26
SPI_SETKEYBOARDCUES=4107
SPI_SETKEYBOARDDELAY=23
SPI_SETKEYBOARDPREF=69
SPI_SETKEYBOARDSPEED=11
SPI_SETLANGTOGGLE=91
SPI_SETLISTBOXSMOOTHSCROLLING=4103
SPI_SETLOWPOWERACTIVE=85
SPI_SETLOWPOWERTIMEOUT=81
SPI_SETMENUANIMATION=4099
SPI_SETMENUDROPALIGNMENT=28
SPI_SETMENUFADE=4115
SPI_SETMENUSHOWDELAY=107
SPI_SETMENUUNDERLINES=4107
SPI_SETMINIMIZEDMETRICS=44
SPI_SETMOUSE=4
SPI_SETMOUSEBUTTONSWAP=33
SPI_SETMOUSECLICKLOCK=4127
SPI_SETMOUSECLICKLOCKTIME=8201
SPI_SETMOUSEHOVERHEIGHT=101
SPI_SETMOUSEHOVERTIME=103
SPI_SETMOUSEHOVERWIDTH=99
SPI_SETMOUSEKEYS=55
SPI_SETMOUSESONAR=4125
SPI_SETMOUSESPEED=113
SPI_SETMOUSETRAILS=93
SPI_SETMOUSEVANISH=4129
SPI_SETNONCLIENTMETRICS=42
SPI_SETPENWINDOWS=49
SPI_SETPOWEROFFACTIVE=86
SPI_SETPOWEROFFTIMEOUT=82
SPI_SETSCREENREADER=71
SPI_SETSCREENSAVEACTIVE=17
SPI_SETSCREENSAVERRUNNING=97
SPI_SETSCREENSAVETIMEOUT=15
SPI_SETSELECTIONFADE=4117
SPI_SETSERIALKEYS=63
SPI_SETSHOWIMEUI=111
SPI_SETSHOWSOUNDS=57
SPI_SETSNAPTODEFBUTTON=96
SPI_SETSOUNDSENTRY=65
SPI_SETSTICKYKEYS=59
SPI_SETTOGGLEKEYS=53
SPI_SETTOOLTIPANIMATION=4119
SPI_SETTOOLTIPFADE=4121
SPI_SETUIEFFECTS=4159
SPI_SETWHEELSCROLLLINES=105
SPI_SETWORKAREA=47
SP_APPABORT=-2
SP_ERROR=-1
SP_NOTREPORTED=16384
SP_OUTOFDISK=-4
SP_OUTOFMEMORY=-5
SP_USERABORT=-3
SRCAND=8913094
SRCCOPY=13369376
SRCERASE=4457256
SRCINVERT=6684742
SRCPAINT=15597702
SSF_AVAILABLE=2
SSF_INDICATOR=4
SSF_SOUNDSENTRYON=1
SSGF_DISPLAY=3
SSGF_NONE=0
SSTF_BORDER=2
SSTF_CHARS=1
SSTF_DISPLAY=3
SSTF_NONE=0
SSWF_CUSTOM=4
SSWF_DISPLAY=3
SSWF_NONE=0
SSWF_TITLE=1
SSWF_WINDOW=2
SS_BITMAP=14
SS_BLACKFRAME=7
SS_BLACKRECT=4
SS_CENTER=1
SS_CENTERIMAGE=512
SS_ELLIPSISMASK=49152
SS_ENDELLIPSIS=16384
SS_ENHMETAFILE=15
SS_ETCHEDFRAME=18
SS_ETCHEDHORZ=16
SS_ETCHEDVERT=17
SS_GRAYFRAME=8
SS_GRAYRECT=5
SS_ICON=3
SS_LEFT=0
SS_LEFTNOWORDWRAP=12
SS_NOPREFIX=128
SS_NOTIFY=256
SS_OWNERDRAW=13
SS_PATHELLIPSIS=32768
SS_REALSIZEIMAGE=2048
SS_RIGHT=2
SS_RIGHTJUST=1024
SS_SIMPLE=11
SS_SUNKEN=4096
SS_TYPEMASK=31
SS_USERITEM=10
SS_WHITEFRAME=9
SS_WHITERECT=6
SS_WORDELLIPSIS=49152
STANDARD_RIGHTS_ALL=2031616
STANDARD_RIGHTS_EXECUTE=131072
STANDARD_RIGHTS_READ=131072
STANDARD_RIGHTS_REQUIRED=983040
STANDARD_RIGHTS_WRITE=131072
STARTDOC=10
STARTF_FORCEOFFFEEDBACK=128
STARTF_FORCEONFEEDBACK=64
STARTF_USECOUNTCHARS=8
STARTF_USEFILLATTRIBUTE=16
STARTF_USEHOTKEY=512
STARTF_USEPOSITION=4
STARTF_USESHOWWINDOW=1
STARTF_USESIZE=2
STARTF_USESTDHANDLES=256
STATE_SYSTEM_ALERT_HIGH=268435456
STATE_SYSTEM_ALERT_LOW=67108864
STATE_SYSTEM_ALERT_MEDIUM=134217728
STATE_SYSTEM_ANIMATED=16384
STATE_SYSTEM_BUSY=2048
STATE_SYSTEM_CHECKED=16
STATE_SYSTEM_COLLAPSED=1024
STATE_SYSTEM_DEFAULT=256
STATE_SYSTEM_EXPANDED=512
STATE_SYSTEM_EXTSELECTABLE=33554432
STATE_SYSTEM_FLOATING=4096
STATE_SYSTEM_FOCUSABLE=1048576
STATE_SYSTEM_FOCUSED=4
STATE_SYSTEM_HOTTRACKED=128
STATE_SYSTEM_INVISIBLE=32768
STATE_SYSTEM_LINKED=4194304
STATE_SYSTEM_MARQUEED=8192
STATE_SYSTEM_MIXED=32
STATE_SYSTEM_MOVEABLE=262144
STATE_SYSTEM_MULTISELECTABLE=16777216
STATE_SYSTEM_OFFSCREEN=65536
STATE_SYSTEM_PRESSED=8
STATE_SYSTEM_READONLY=64
STATE_SYSTEM_SELECTABLE=2097152
STATE_SYSTEM_SELECTED=2
STATE_SYSTEM_SELFVOICING=524288
STATE_SYSTEM_SIZEABLE=131072
STATE_SYSTEM_TRAVERSED=8388608
STATE_SYSTEM_UNAVAILABLE=1
STATE_SYSTEM_VALID=536870911
STATUS_ABANDONED_WAIT_0=128
STATUS_ACCESS_VIOLATION=-1073741819
STATUS_ARRAY_BOUNDS_EXCEEDED=-1073741684
STATUS_BREAKPOINT=-2147483645
STATUS_CONTROL_C_EXIT=-1073741510
STATUS_DATATYPE_MISALIGNMENT=-2147483646
STATUS_FLOAT_DENORMAL_OPERAND=-1073741683
STATUS_FLOAT_DIVIDE_BY_ZERO=-1073741682
STATUS_FLOAT_INEXACT_RESULT=-1073741681
STATUS_FLOAT_INVALID_OPERATION=-1073741680
STATUS_FLOAT_OVERFLOW=-1073741679
STATUS_FLOAT_STACK_CHECK=-1073741678
STATUS_FLOAT_UNDERFLOW=-1073741677
STATUS_GUARD_PAGE_VIOLATION=-2147483647
STATUS_ILLEGAL_INSTRUCTION=-1073741795
STATUS_INTEGER_DIVIDE_BY_ZERO=-1073741676
STATUS_INTEGER_OVERFLOW=-1073741675
STATUS_INVALID_DISPOSITION=-1073741786
STATUS_INVALID_HANDLE=-1073741816
STATUS_IN_PAGE_ERROR=-1073741818
STATUS_NONCONTINUABLE_EXCEPTION=-1073741787
STATUS_NO_MEMORY=-1073741801
STATUS_PENDING=259
STATUS_PRIVILEGED_INSTRUCTION=-1073741674
STATUS_SEGMENT_NOTIFICATION=1073741829
STATUS_SINGLE_STEP=-2147483644
STATUS_STACK_OVERFLOW=-1073741571
STATUS_TIMEOUT=258
STATUS_USER_APC=192
STATUS_WAIT_0=0
STILL_ACTIVE=259
STM_GETICON=369
STM_GETIMAGE=371
STM_MSGMAX=372
STM_SETICON=368
STM_SETIMAGE=370
STN_CLICKED=0
STN_DBLCLK=1
STN_DISABLE=3
STN_ENABLE=2
STOCK_LAST=16
STREAM_CONTAINS_PROPERTIES=4
STREAM_CONTAINS_SECURITY=2
STREAM_MODIFIED_WHEN_READ=1
STREAM_NORMAL_ATTRIBUTE=0
STRETCHBLT=2048
STRETCH_ANDSCANS=1
STRETCH_DELETESCANS=3
STRETCH_HALFTONE=4
STRETCH_ORSCANS=2
SUBLANG_CHINESE_HONGKONG=3
SUBLANG_CHINESE_SIMPLIFIED=2
SUBLANG_CHINESE_SINGAPORE=4
SUBLANG_CHINESE_TRADITIONAL=1
SUBLANG_DEFAULT=1
SUBLANG_DUTCH=1
SUBLANG_DUTCH_BELGIAN=2
SUBLANG_ENGLISH_AUS=3
SUBLANG_ENGLISH_CAN=4
SUBLANG_ENGLISH_EIRE=6
SUBLANG_ENGLISH_NZ=5
SUBLANG_ENGLISH_UK=2
SUBLANG_ENGLISH_US=1
SUBLANG_FRENCH=1
SUBLANG_FRENCH_BELGIAN=2
SUBLANG_FRENCH_CANADIAN=3
SUBLANG_FRENCH_SWISS=4
SUBLANG_GERMAN=1
SUBLANG_GERMAN_AUSTRIAN=3
SUBLANG_GERMAN_SWISS=2
SUBLANG_ITALIAN=1
SUBLANG_ITALIAN_SWISS=2
SUBLANG_NEUTRAL=0
SUBLANG_NORWEGIAN_BOKMAL=1
SUBLANG_NORWEGIAN_NYNORSK=2
SUBLANG_PORTUGUESE=2
SUBLANG_PORTUGUESE_BRAZILIAN=1
SUBLANG_SPANISH=1
SUBLANG_SPANISH_MEXICAN=2
SUBLANG_SPANISH_MODERN=3
SUBLANG_SYS_DEFAULT=2
SUCCESSFUL_ACCESS_ACE_FLAG=64
SWP_ASYNCWINDOWPOS=16384
SWP_DEFERERASE=8192
SWP_DRAWFRAME=32
SWP_FRAMECHANGED=32
SWP_HIDEWINDOW=128
SWP_NOACTIVATE=16
SWP_NOCOPYBITS=256
SWP_NOMOVE=2
SWP_NOOWNERZORDER=512
SWP_NOREDRAW=8
SWP_NOREPOSITION=512
SWP_NOSENDCHANGING=1024
SWP_NOSIZE=1
SWP_NOZORDER=4
SWP_SHOWWINDOW=64
SW_ERASE=4
SW_FORCEMINIMIZE=11
SW_HIDE=0
SW_INVALIDATE=2
SW_MAX=11
SW_MAXIMIZE=3
SW_MINIMIZE=6
SW_NORMAL=1
SW_OTHERUNZOOM=4
SW_OTHERZOOM=2
SW_PARENTCLOSING=1
SW_PARENTOPENING=3
SW_RESTORE=9
SW_SCROLLCHILDREN=1
SW_SHOW=5
SW_SHOWDEFAULT=10
SW_SHOWMAXIMIZED=3
SW_SHOWMINIMIZED=2
SW_SHOWMINNOACTIVE=7
SW_SHOWNA=8
SW_SHOWNOACTIVATE=4
SW_SHOWNORMAL=1
SW_SMOOTHSCROLL=16
SYMBOL_CHARSET=2
SYNCHRONIZE=1048576
SYSPAL_ERROR=0
SYSPAL_NOSTATIC=2
SYSPAL_STATIC=1
SYSTEM_ALARM_ACE_TYPE=3
SYSTEM_AUDIT_ACE_TYPE=2
SYSTEM_FIXED_FONT=16
SYSTEM_FONT=13
S_ALLTHRESHOLD=2
S_LEGATO=1
S_NORMAL=0
S_QUEUEEMPTY=0
S_STACCATO=2
S_THRESHOLD=1
TAPE_ABSOLUTE_BLOCK=1
TAPE_ABSOLUTE_POSITION=0
TAPE_DRIVE_ABSOLUTE_BLK=-2147479552
TAPE_DRIVE_ABS_BLK_IMMED=-2147475456
TAPE_DRIVE_COMPRESSION=131072
TAPE_DRIVE_ECC=65536
TAPE_DRIVE_END_OF_DATA=-2147418112
TAPE_DRIVE_EOT_WZ_SIZE=8192
TAPE_DRIVE_ERASE_BOP_ONLY=64
TAPE_DRIVE_ERASE_IMMEDIATE=128
TAPE_DRIVE_ERASE_LONG=32
TAPE_DRIVE_ERASE_SHORT=16
TAPE_DRIVE_FILEMARKS=-2147221504
TAPE_DRIVE_FIXED=1
TAPE_DRIVE_FIXED_BLOCK=1024
TAPE_DRIVE_FORMAT=-1610612736
TAPE_DRIVE_FORMAT_IMMEDIATE=-1073741824
TAPE_DRIVE_GET_ABSOLUTE_BLK=1048576
TAPE_DRIVE_GET_LOGICAL_BLK=2097152
TAPE_DRIVE_INITIATOR=4
TAPE_DRIVE_LOAD_UNLD_IMMED=-2147483616
TAPE_DRIVE_LOAD_UNLOAD=-2147483647
TAPE_DRIVE_LOCK_UNLK_IMMED=-2147483520
TAPE_DRIVE_LOCK_UNLOCK=-2147483644
TAPE_DRIVE_LOGICAL_BLK=-2147467264
TAPE_DRIVE_LOG_BLK_IMMED=-2147450880
TAPE_DRIVE_PADDING=262144
TAPE_DRIVE_RELATIVE_BLKS=-2147352576
TAPE_DRIVE_REPORT_SMKS=524288
TAPE_DRIVE_REVERSE_POSITION=-2143289344
TAPE_DRIVE_REWIND_IMMEDIATE=-2147483640
TAPE_DRIVE_SELECT=2
TAPE_DRIVE_SEQUENTIAL_FMKS=-2146959360
TAPE_DRIVE_SEQUENTIAL_SMKS=-2145386496
TAPE_DRIVE_SETMARKS=-2146435072
TAPE_DRIVE_SET_BLOCK_SIZE=-2147483632
TAPE_DRIVE_SET_COMPRESSION=-2147483136
TAPE_DRIVE_SET_ECC=-2147483392
TAPE_DRIVE_SET_EOT_WZ_SIZE=4194304
TAPE_DRIVE_SET_PADDING=-2147482624
TAPE_DRIVE_SET_REPORT_SMKS=-2147481600
TAPE_DRIVE_SPACE_IMMEDIATE=-2139095040
TAPE_DRIVE_TAPE_CAPACITY=256
TAPE_DRIVE_TAPE_REMAINING=512
TAPE_DRIVE_TENSION=-2147483646
TAPE_DRIVE_TENSION_IMMED=-2147483584
TAPE_DRIVE_VARIABLE_BLOCK=2048
TAPE_DRIVE_WRITE_FILEMARKS=-2113929216
TAPE_DRIVE_WRITE_LONG_FMKS=-2013265920
TAPE_DRIVE_WRITE_MARK_IMMED=-1879048192
TAPE_DRIVE_WRITE_PROTECT=4096
TAPE_DRIVE_WRITE_SETMARKS=-2130706432
TAPE_DRIVE_WRITE_SHORT_FMKS=-2080374784
TAPE_ERASE_LONG=1
TAPE_ERASE_SHORT=0
TAPE_FILEMARKS=1
TAPE_FIXED_PARTITIONS=0
TAPE_FORMAT=5
TAPE_INITIATOR_PARTITIONS=2
TAPE_LOAD=0
TAPE_LOCK=3
TAPE_LOGICAL_BLOCK=2
TAPE_LOGICAL_POSITION=1
TAPE_LONG_FILEMARKS=3
TAPE_PSEUDO_LOGICAL_BLOCK=3
TAPE_PSEUDO_LOGICAL_POSITION=2
TAPE_REWIND=0
TAPE_SELECT_PARTITIONS=1
TAPE_SETMARKS=0
TAPE_SHORT_FILEMARKS=2
TAPE_SPACE_END_OF_DATA=4
TAPE_SPACE_FILEMARKS=6
TAPE_SPACE_RELATIVE_BLOCKS=5
TAPE_SPACE_SEQUENTIAL_FMKS=7
TAPE_SPACE_SEQUENTIAL_SMKS=9
TAPE_SPACE_SETMARKS=8
TAPE_TENSION=2
TAPE_UNLOAD=1
TAPE_UNLOCK=4
TA_BASELINE=24
TA_BOTTOM=8
TA_CENTER=6
TA_LEFT=0
TA_MASK=31
TA_NOUPDATECP=0
TA_RIGHT=2
TA_TOP=0
TA_UPDATECP=1
TC_CP_STROKE=4
TC_CR_90=8
TC_CR_ANY=16
TC_EA_DOUBLE=512
TC_GP_TRAP=2
TC_HARDERR=1
TC_IA_ABLE=1024
TC_NORMAL=0
TC_OP_CHARACTER=1
TC_OP_STROKE=2
TC_RA_ABLE=8192
TC_RESERVED=32768
TC_SA_CONTIN=256
TC_SA_DOUBLE=64
TC_SA_INTEGER=128
TC_SCROLLBLT=65536
TC_SF_X_YINDEP=32
TC_SIGNAL=3
TC_SO_ABLE=4096
TC_UA_ABLE=2048
TC_VA_ABLE=16384
TECHNOLOGY=2
TEXTCAPS=34
THAI_CHARSET=222
THREAD_BASE_PRIORITY_IDLE=-15
THREAD_BASE_PRIORITY_LOWRT=15
THREAD_BASE_PRIORITY_MAX=2
THREAD_BASE_PRIORITY_MIN=-2
THREAD_DIRECT_IMPERSONATION=512
THREAD_GET_CONTEXT=8
THREAD_IMPERSONATE=256
THREAD_MODE_BACKGROUND_BEGIN=65536
THREAD_MODE_BACKGROUND_END=131072
THREAD_PRIORITY_ABOVE_NORMAL=1
THREAD_PRIORITY_BELOW_NORMAL=-1
THREAD_PRIORITY_ERROR_RETURN=2147483647
THREAD_PRIORITY_HIGHEST=2
THREAD_PRIORITY_IDLE=-15
THREAD_PRIORITY_LOWEST=-2
THREAD_PRIORITY_NORMAL=0
THREAD_PRIORITY_TIME_CRITICAL=15
THREAD_QUERY_INFORMATION=64
THREAD_SET_CONTEXT=16
THREAD_SET_INFORMATION=32
THREAD_SET_THREAD_TOKEN=128
THREAD_SUSPEND_RESUME=2
THREAD_TERMINATE=1
TIME_ZONE_ID_DAYLIGHT=2
TIME_ZONE_ID_STANDARD=1
TIME_ZONE_ID_UNKNOWN=0
TKF_AVAILABLE=2
TKF_CONFIRMHOTKEY=8
TKF_HOTKEYACTIVE=4
TKF_HOTKEYSOUND=16
TKF_INDICATOR=32
TKF_TOGGLEKEYSON=1
TLS_MINIMUM_AVAILABLE=64
TME_CANCEL=-2147483648
TME_HOVER=1
TME_LEAVE=2
TME_QUERY=1073741824
TMPF_DEVICE=8
TMPF_FIXED_PITCH=1
TMPF_TRUETYPE=4
TMPF_VECTOR=2
TOKEN_ADJUST_DEFAULT=128
TOKEN_ADJUST_GROUPS=64
TOKEN_ADJUST_PRIVILEGES=32
TOKEN_ALL_ACCESS=983295
TOKEN_ASSIGN_PRIMARY=1
TOKEN_DUPLICATE=2
TOKEN_EXECUTE=131072
TOKEN_IMPERSONATE=4
TOKEN_QUERY=8
TOKEN_QUERY_SOURCE=16
TOKEN_READ=131080
TOKEN_SOURCE_LENGTH=8
TOKEN_WRITE=131296
TPM_BOTTOMALIGN=32
TPM_CENTERALIGN=4
TPM_HORIZONTAL=0
TPM_LEFTALIGN=0
TPM_LEFTBUTTON=0
TPM_NONOTIFY=128
TPM_RECURSE=1
TPM_RETURNCMD=256
TPM_RIGHTALIGN=8
TPM_RIGHTBUTTON=2
TPM_TOPALIGN=0
TPM_VCENTERALIGN=16
TPM_VERTICAL=64
TRANSFORM_CTM=4107
TRANSPARENT=1
TRUE=1
TRUETYPE_FONTTYPE=4
TRUNCATE_EXISTING=5
TT_AVAILABLE=1
TT_ENABLED=2
TT_POLYGON_TYPE=24
TT_PRIM_LINE=1
TT_PRIM_QSPLINE=2
TURKISH_CHARSET=162
TWOSTOPBITS=2
TYPE1_FONTTYPE=131072
ULW_ALPHA=2
ULW_COLORKEY=1
ULW_OPAQUE=4
UNLOAD_DLL_DEBUG_EVENT=7
UOI_FLAGS=1
UOI_NAME=2
UOI_TYPE=3
UOI_USER_SID=4
VALID_INHERIT_FLAGS=15
VARIABLE_PITCH=2
VERTRES=10
VERTSIZE=6
VER_PLATFORM_WIN32_NT=2
VER_PLATFORM_WIN32_WINDOWS=1
VER_PLATFORM_WIN32s=0
VIETNAMESE_CHARSET=163
VK_ACCEPT=30
VK_ADD=107
VK_APPS=93
VK_ATTN=246
VK_BACK=8
VK_BROWSER_BACK=166
VK_BROWSER_FORWARD=167
VK_CANCEL=3
VK_CAPITAL=20
VK_CLEAR=12
VK_CONTROL=17
VK_CONVERT=28
VK_CRSEL=247
VK_DECIMAL=110
VK_DELETE=46
VK_DIVIDE=111
VK_DOWN=40
VK_END=35
VK_EREOF=249
VK_ESCAPE=27
VK_EXECUTE=43
VK_EXSEL=248
VK_F1=112
VK_F10=121
VK_F11=122
VK_F12=123
VK_F13=124
VK_F14=125
VK_F15=126
VK_F16=127
VK_F17=128
VK_F18=129
VK_F19=130
VK_F2=113
VK_F20=131
VK_F21=132
VK_F22=133
VK_F23=134
VK_F24=135
VK_F3=114
VK_F4=115
VK_F5=116
VK_F6=117
VK_F7=118
VK_F8=119
VK_F9=120
VK_FINAL=24
VK_HANGEUL=21
VK_HANGUL=21
VK_HANJA=25
VK_HELP=47
VK_HOME=36
VK_INSERT=45
VK_JUNJA=23
VK_KANA=21
VK_KANJI=25
VK_LBUTTON=1
VK_LCONTROL=162
VK_LEFT=37
VK_LMENU=164
VK_LSHIFT=160
VK_LWIN=91
VK_MBUTTON=4
VK_MEDIA_NEXT_TRACK=176
VK_MEDIA_PLAY_PAUSE=179
VK_MEDIA_PREV_TRACK=177
VK_MENU=18
VK_MODECHANGE=31
VK_MULTIPLY=106
VK_NEXT=34
VK_NONAME=252
VK_NONCONVERT=29
VK_NUMLOCK=144
VK_NUMPAD0=96
VK_NUMPAD1=97
VK_NUMPAD2=98
VK_NUMPAD3=99
VK_NUMPAD4=100
VK_NUMPAD5=101
VK_NUMPAD6=102
VK_NUMPAD7=103
VK_NUMPAD8=104
VK_NUMPAD9=105
VK_OEM_CLEAR=254
VK_PA1=253
VK_PAUSE=19
VK_PLAY=250
VK_PRINT=42
VK_PRIOR=33
VK_PROCESSKEY=229
VK_RBUTTON=2
VK_RCONTROL=163
VK_RETURN=13
VK_RIGHT=39
VK_RMENU=165
VK_RSHIFT=161
VK_RWIN=92
VK_SCROLL=145
VK_SELECT=41
VK_SEPARATOR=108
VK_SHIFT=16
VK_SNAPSHOT=44
VK_SPACE=32
VK_SUBTRACT=109
VK_TAB=9
VK_UP=38
VK_VOLUME_DOWN=174
VK_VOLUME_MUTE=173
VK_VOLUME_UP=175
VK_XBUTTON1=5
VK_XBUTTON2=6
VK_ZOOM=251
VOLUME_NAME_DOS=0
VOLUME_NAME_GUID=1
VOLUME_NAME_NONE=4
VOLUME_NAME_NT=2
VREFRESH=116
VTA_BASELINE=24
VTA_BOTTOM=2
VTA_CENTER=6
VTA_LEFT=8
VTA_RIGHT=0
VTA_TOP=0
WAIT_ABANDONED=128
WAIT_ABANDONED_0=128
WAIT_FAILED=-1
WAIT_IO_COMPLETION=192
WAIT_OBJECT_0=0
WAIT_TIMEOUT=258
WA_ACTIVE=1
WA_CLICKACTIVE=2
WA_INACTIVE=0
WBF_CUSTOM=512
WBF_LEVEL1=128
WBF_LEVEL2=256
WBF_OVERFLOW=64
WBF_WORDBREAK=32
WBF_WORDWRAP=16
WB_CLASSIFY=3
WB_ISDELIMITER=2
WB_LEFT=0
WB_LEFTBREAK=6
WB_MOVEWORDLEFT=4
WB_MOVEWORDNEXT=5
WB_MOVEWORDPREV=4
WB_MOVEWORDRIGHT=5
WB_NEXTBREAK=7
WB_PREVBREAK=6
WB_RIGHT=1
WB_RIGHTBREAK=7
WHEEL_DELTA=120
WHEEL_PAGESCROLL=-1
WHITENESS=16711778
WHITEONBLACK=2
WHITE_BRUSH=0
WHITE_PEN=6
WH_CALLWNDPROC=4
WH_CALLWNDPROCRET=12
WH_CBT=5
WH_DEBUG=9
WH_FOREGROUNDIDLE=11
WH_GETMESSAGE=3
WH_HARDWARE=8
WH_JOURNALPLAYBACK=1
WH_JOURNALRECORD=0
WH_KEYBOARD=2
WH_KEYBOARD_LL=13
WH_MAX=14
WH_MAXHOOK=14
WH_MIN=-1
WH_MINHOOK=-1
WH_MOUSE=7
WH_MOUSE_LL=14
WH_MSGFILTER=-1
WH_SHELL=10
WH_SYSMSGFILTER=6
WINDING=2
WINEVENT_INCONTEXT=4
WINEVENT_OUTOFCONTEXT=0
WINEVENT_SKIPOWNPROCESS=2
WINEVENT_SKIPOWNTHREAD=1
WINSTA_ACCESSCLIPBOARD=4
WINSTA_ACCESSGLOBALATOMS=32
WINSTA_CREATEDESKTOP=8
WINSTA_ENUMDESKTOPS=1
WINSTA_ENUMERATE=256
WINSTA_EXITWINDOWS=64
WINSTA_READATTRIBUTES=2
WINSTA_READSCREEN=512
WINSTA_WRITEATTRIBUTES=16
WINVER=1280
WMSZ_BOTTOM=6
WMSZ_BOTTOMLEFT=7
WMSZ_BOTTOMRIGHT=8
WMSZ_LEFT=1
WMSZ_RIGHT=2
WMSZ_TOP=3
WMSZ_TOPLEFT=4
WMSZ_TOPRIGHT=5
WM_ACTIVATE=6
WM_ACTIVATEAPP=28
WM_AFXFIRST=864
WM_AFXLAST=895
WM_APP=32768
WM_ASKCBFORMATNAME=780
WM_CANCELJOURNAL=75
WM_CANCELMODE=31
WM_CAPTURECHANGED=533
WM_CHANGECBCHAIN=781
WM_CHAR=258
WM_CHARTOITEM=47
WM_CHILDACTIVATE=34
WM_CHOOSEFONT_GETLOGFONT=1025
WM_CHOOSEFONT_SETFLAGS=1126
WM_CHOOSEFONT_SETLOGFONT=1125
WM_CLEAR=771
WM_CLOSE=16
WM_COMMAND=273
WM_COMMNOTIFY=68
WM_COMPACTING=65
WM_COMPAREITEM=57
WM_CONTEXTMENU=123
WM_COPY=769
WM_COPYDATA=74
WM_CREATE=1
WM_CTLCOLORBTN=309
WM_CTLCOLORDLG=310
WM_CTLCOLOREDIT=307
WM_CTLCOLORLISTBOX=308
WM_CTLCOLORMSGBOX=306
WM_CTLCOLORSCROLLBAR=311
WM_CTLCOLORSTATIC=312
WM_CUT=768
WM_DEADCHAR=259
WM_DELETEITEM=45
WM_DESTROY=2
WM_DESTROYCLIPBOARD=775
WM_DEVICECHANGE=537
WM_DEVMODECHANGE=27
WM_DISPLAYCHANGE=126
WM_DRAWCLIPBOARD=776
WM_DRAWITEM=43
WM_DROPFILES=563
WM_ENABLE=10
WM_ENDSESSION=22
WM_ENTERIDLE=289
WM_ENTERMENULOOP=529
WM_ENTERSIZEMOVE=561
WM_ERASEBKGND=20
WM_EXITMENULOOP=530
WM_EXITSIZEMOVE=562
WM_FONTCHANGE=29
WM_GETDLGCODE=135
WM_GETFONT=49
WM_GETHOTKEY=51
WM_GETICON=127
WM_GETMINMAXINFO=36
WM_GETOBJECT=61
WM_GETTEXT=13
WM_GETTEXTLENGTH=14
WM_HANDHELDFIRST=856
WM_HANDHELDLAST=863
WM_HELP=83
WM_HOTKEY=786
WM_HSCROLL=276
WM_HSCROLLCLIPBOARD=782
WM_ICONERASEBKGND=39
WM_IME_CHAR=646
WM_IME_COMPOSITION=271
WM_IME_COMPOSITIONFULL=644
WM_IME_CONTROL=643
WM_IME_ENDCOMPOSITION=270
WM_IME_KEYDOWN=656
WM_IME_KEYLAST=271
WM_IME_KEYUP=657
WM_IME_NOTIFY=642
WM_IME_REQUEST=648
WM_IME_SELECT=645
WM_IME_SETCONTEXT=641
WM_IME_STARTCOMPOSITION=269
WM_INITDIALOG=272
WM_INITMENU=278
WM_INITMENUPOPUP=279
WM_INPUTLANGCHANGE=81
WM_INPUTLANGCHANGEREQUEST=80
WM_KEYDOWN=256
WM_KEYFIRST=256
WM_KEYLAST=264
WM_KEYUP=257
WM_KILLFOCUS=8
WM_LBUTTONDBLCLK=515
WM_LBUTTONDOWN=513
WM_LBUTTONUP=514
WM_MBUTTONDBLCLK=521
WM_MBUTTONDOWN=519
WM_MBUTTONUP=520
WM_MDIACTIVATE=546
WM_MDICASCADE=551
WM_MDICREATE=544
WM_MDIDESTROY=545
WM_MDIGETACTIVE=553
WM_MDIICONARRANGE=552
WM_MDIMAXIMIZE=549
WM_MDINEXT=548
WM_MDIREFRESHMENU=564
WM_MDIRESTORE=547
WM_MDISETMENU=560
WM_MDITILE=550
WM_MEASUREITEM=44
WM_MENUCHAR=288
WM_MENUCOMMAND=294
WM_MENUDRAG=291
WM_MENUGETOBJECT=292
WM_MENURBUTTONUP=290
WM_MENUSELECT=287
WM_MOUSEACTIVATE=33
WM_MOUSEFIRST=512
WM_MOUSEHOVER=673
WM_MOUSELAST=522
WM_MOUSELEAVE=675
WM_MOUSEMOVE=512
WM_MOUSEWHEEL=522
WM_MOUSEHWHEEL=526
WM_MOVE=3
WM_MOVING=534
WM_NCACTIVATE=134
WM_NCCALCSIZE=131
WM_NCCREATE=129
WM_NCDESTROY=130
WM_NCHITTEST=132
WM_NCLBUTTONDBLCLK=163
WM_NCLBUTTONDOWN=161
WM_NCLBUTTONUP=162
WM_NCMBUTTONDBLCLK=169
WM_NCMBUTTONDOWN=167
WM_NCMBUTTONUP=168
WM_NCMOUSEMOVE=160
WM_NCPAINT=133
WM_NCRBUTTONDBLCLK=166
WM_NCRBUTTONDOWN=164
WM_NCRBUTTONUP=165
WM_NEXTDLGCTL=40
WM_NEXTMENU=531
WM_NOTIFY=78
WM_NOTIFYFORMAT=85
WM_NULL=0
WM_PAINT=15
WM_PAINTCLIPBOARD=777
WM_PAINTICON=38
WM_PALETTECHANGED=785
WM_PALETTEISCHANGING=784
WM_PARENTNOTIFY=528
WM_PASTE=770
WM_PENWINFIRST=896
WM_PENWINLAST=911
WM_POWER=72
WM_POWERBROADCAST=536
WM_PRINT=791
WM_PRINTCLIENT=792
WM_PSD_ENVSTAMPRECT=1029
WM_PSD_FULLPAGERECT=1025
WM_PSD_GREEKTEXTRECT=1028
WM_PSD_MARGINRECT=1027
WM_PSD_MINMARGINRECT=1026
WM_PSD_PAGESETUPDLG=1024
WM_PSD_YAFULLPAGERECT=1030
WM_QUERYDRAGICON=55
WM_QUERYENDSESSION=17
WM_QUERYNEWPALETTE=783
WM_QUERYOPEN=19
WM_QUEUESYNC=35
WM_QUIT=18
WM_RBUTTONDBLCLK=518
WM_RBUTTONDOWN=516
WM_RBUTTONUP=517
WM_RENDERALLFORMATS=774
WM_RENDERFORMAT=773
WM_SETCURSOR=32
WM_SETFOCUS=7
WM_SETFONT=48
WM_SETHOTKEY=50
WM_SETICON=128
WM_SETREDRAW=11
WM_SETTEXT=12
WM_SETTINGCHANGE=26
WM_SHOWWINDOW=24
WM_SIZE=5
WM_SIZECLIPBOARD=779
WM_SIZING=532
WM_SPOOLERSTATUS=42
WM_STYLECHANGED=125
WM_STYLECHANGING=124
WM_SYNCPAINT=136
WM_SYSCHAR=262
WM_SYSCOLORCHANGE=21
WM_SYSCOMMAND=274
WM_SYSDEADCHAR=263
WM_SYSKEYDOWN=260
WM_SYSKEYUP=261
WM_TCARD=82
WM_TIMECHANGE=30
WM_TIMER=275
WM_UNDO=772
WM_UNINITMENUPOPUP=293
WM_USER=1024
WM_USERCHANGED=84
WM_VKEYTOITEM=46
WM_VSCROLL=277
WM_VSCROLLCLIPBOARD=778
WM_WINDOWPOSCHANGED=71
WM_WINDOWPOSCHANGING=70
WM_WININICHANGE=26
WPF_RESTORETOMAXIMIZED=2
WPF_SETMINPOSITION=1
WRITE_DAC=262144
WRITE_OWNER=524288
WSF_VISIBLE=1
WS_ACTIVECAPTION=1
WS_BORDER=8388608
WS_CAPTION=12582912
WS_CHILD=1073741824
WS_CHILDWINDOW=1073741824
WS_CLIPCHILDREN=33554432
WS_CLIPSIBLINGS=67108864
WS_DISABLED=134217728
WS_DLGFRAME=4194304
WS_EX_ACCEPTFILES=16
WS_EX_APPWINDOW=262144
WS_EX_CLIENTEDGE=512
WS_EX_COMPOSITED=33554432
WS_EX_CONTEXTHELP=1024
WS_EX_CONTROLPARENT=65536
WS_EX_DLGMODALFRAME=1
WS_EX_LAYERED=524288
WS_EX_LAYOUTRTL=4194304
WS_EX_LEFT=0
WS_EX_LEFTSCROLLBAR=16384
WS_EX_LTRREADING=0
WS_EX_MDICHILD=64
WS_EX_NOACTIVATE=134217728
WS_EX_NOINHERITLAYOUT=1048576
WS_EX_NOPARENTNOTIFY=4
WS_EX_OVERLAPPEDWINDOW=768
WS_EX_PALETTEWINDOW=392
WS_EX_RIGHT=4096
WS_EX_RIGHTSCROLLBAR=0
WS_EX_RTLREADING=8192
WS_EX_STATICEDGE=131072
WS_EX_TOOLWINDOW=128
WS_EX_TOPMOST=8
WS_EX_TRANSPARENT=32
WS_EX_WINDOWEDGE=256
WS_GROUP=131072
WS_HSCROLL=1048576
WS_ICONIC=536870912
WS_MAXIMIZE=16777216
WS_MAXIMIZEBOX=65536
WS_MINIMIZE=536870912
WS_MINIMIZEBOX=131072
WS_OVERLAPPED=0
WS_OVERLAPPEDWINDOW=13565952
WS_POPUP=-2147483648
WS_POPUPWINDOW=-2138570752
WS_SIZEBOX=262144
WS_SYSMENU=524288
WS_TABSTOP=65536
WS_THICKFRAME=262144
WS_TILED=0
WS_TILEDWINDOW=13565952
WS_VISIBLE=268435456
WS_VSCROLL=2097152
WVR_ALIGNBOTTOM=64
WVR_ALIGNLEFT=32
WVR_ALIGNRIGHT=128
WVR_ALIGNTOP=16
WVR_HREDRAW=256
WVR_REDRAW=768
WVR_VALIDRECTS=1024
WVR_VREDRAW=512
XBUTTON1=1
XBUTTON2=2
cchTextLimitDefault=32767
lDefaultTab=720
yHeightCharPtsMost=1638
